@@ -80,7 +80,7 @@ AGUIX *AWindow::getAGUIX() const
   return _aguix;
 }
 
-void AWindow::sizeChanged(int width,int height)
+void AWindow::sizeChanged(int width,int height, bool explicit_resize)
 {
   if ( width != _w || height != _h ) {
     AGMessage *agmsg = AGUIX_allocAGMessage();
@@ -88,6 +88,7 @@ void AWindow::sizeChanged(int width,int height)
     agmsg->size.window=win;
     agmsg->size.neww=width;
     agmsg->size.newh=height;
+    agmsg->size.explicit_resize = explicit_resize;
     _aguix->putAGMsg(agmsg);
     _w = width;
     _h = height;
@@ -350,7 +351,7 @@ bool AWindow::handleMessage(XEvent *E,Message *msg)
         if ( ( msg->width != msgW ) || ( msg->height != msgH ) ) {
           msgW = msg->width;
           msgH = msg->height;
-          sizeChanged( msg->width, msg->height );
+          sizeChanged( msg->width, msg->height, false );
 	}
       }
     }
@@ -535,7 +536,7 @@ void AWindow::resize(int nw,int nh)
       _w = nw;
       _h = nh;
 #else
-      sizeChanged( nw, nh );
+      sizeChanged( nw, nh, true );
 #endif
     }
   }
