@@ -1,6 +1,6 @@
 /* button.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2014 Ralf Hoffmann.
+ * Copyright (C) 2001-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -23,6 +23,7 @@
 #include "awindow.h"
 #include "guielement.h"
 #include "drawablecont.hh"
+#include "aicon.hh"
 
 const char *Button::type="Button";
 
@@ -388,6 +389,7 @@ void Button::redraw()
   unsigned int ear_width = 0 ;
   int bw;
   int text_color;
+  int background;
 
   if ( isCreated() == false ) return;
   if ( win == 0 ) return;
@@ -421,8 +423,10 @@ void Button::redraw()
 
   if ( ( dual == false ) || ( state != 2 ) ) {
     text_color = fg[0];
+    background = bg[0];
   } else {
     text_color = fg[1];
+    background = bg[1];
   }
   if(font==NULL) {
     ch=_aguix->getCharHeight();
@@ -440,15 +444,49 @@ void Button::redraw()
 
   bw = 2;
 
-  len = _aguix->getStrlen4Width( tstr, _w - 2 * bw, &strwidth, font );
-  if ( len >= 0 ) {
+  int icon_width = 0;
+  int icon_height = 0;
+  int icon_space = 0;
+
+  if ( m_icon ) {
+      m_icon->update( win, text_color, background, false );
+
+      icon_width = m_icon->w();
+      icon_height = m_icon->h();
+      icon_space = 5;
+  }
+
+  len = _aguix->getStrlen4Width( tstr, _w - 2 * bw - icon_width - icon_space, &strwidth, font );
+  if ( len > 0 ) {
     if ( len >= (int)strlen( tstr ) ) len = (int)strlen( tstr );
     tstr[len] = '\0';
 
-    int dx = _w / 2 - strwidth / 2;
+    int dx = _w / 2 - ( icon_width + icon_space + strwidth ) / 2;
     
     DrawableCont dc( _aguix, win );
-    _aguix->DrawText( dc, font, tstr, dx, dy, text_color );
+
+    if ( m_icon_pos == ICON_RIGHT ) {
+        _aguix->DrawText( dc, font, tstr, dx, dy, text_color );
+    } else {
+        _aguix->DrawText( dc, font, tstr, dx + icon_width + icon_space, dy, text_color );
+    }
+
+    if ( m_icon ) {
+        if ( m_icon_pos == ICON_RIGHT ) {
+            m_icon->draw( win,
+                          dx + strwidth + icon_space,
+                          _h / 2 - icon_height / 2 );
+        } else {
+            m_icon->draw( win,
+                          dx, _h / 2 - icon_height / 2 );
+        }
+    }
+  } else {
+      if ( m_icon ) {
+          int dx = _w / 2 - icon_width / 2;
+    
+          m_icon->draw( win, dx, _h / 2 - icon_height / 2 );
+      }
   }
   _freesafe( tstr );
 
@@ -768,3 +806,25 @@ void Button::applyFaces()
         bg[1] = _aguix->getFaces().getColor( "button-alt-bg" );
     }
 }
+
+void Button::setIcon( const int *pixels,
+                      size_t pixels_length,
+                      icon_position pos )
+{
+    m_icon = std::make_shared< AIcon >( _aguix,
+                                        win,
+                                        pixels,
+                                        pixels_length );
+    m_icon_pos = pos;
+}
+
+int Button::getPreferredHeight()
+{
+    int bw = 2;
+
+    if ( font == NULL ) {
+        return _aguix->getCharHeight() + 2 * bw;
+    } else {
+        return font->getCharHeight() + 2 * bw;
+    }
+}
