@@ -1,6 +1,6 @@
 /* lowlevelfunc.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -323,7 +323,9 @@ char *AGUIX_catTrustedAndUnTrusted( const char *str1, const char *str2 )
     if ( str2[i] == '\'' ) sqcount++;
   }
   // for every single quote we need 3 additional chars
-  newstr2 = (char*)_allocsafe( lenstr2 + sqcount * 3 + 1 );
+  newstr2 = (char*)_allocsafe( lenstr2 + sqcount * 3 +
+                               1 /* null byte */ +
+                               3 /* additional dummy bytes for optimized strlen */ );
   for ( i = 0, o = 0; i < lenstr2; i++ ) {
     if ( str2[i] == '\'' ) {
       newstr2[o++] = '\'';
@@ -336,6 +338,11 @@ char *AGUIX_catTrustedAndUnTrusted( const char *str1, const char *str2 )
   }
   newstr2[o] = '\0';
 
+  /* just to keep optimized strlen and co quiet */
+  newstr2[o+1] = '\0';
+  newstr2[o+2] = '\0';
+  newstr2[o+3] = '\0';
+
   // newfilename is now okay
   // space needed for newstr1:
   // str1len
