@@ -182,9 +182,9 @@ void Slider::redraw()
   // draw background
   if ( displayFocus == true ) {
     if ( getHasFocus() == true ) {
-      _aguix->setFG( 1 );
+      _aguix->setFG( _aguix->getFaceCol_3d_dark() );
     } else {
-      _aguix->setFG( 2 );
+      _aguix->setFG( _aguix->getFaceCol_3d_bright() );
     }
     p[0].x = 0;
     p[0].y = _h - 1;
@@ -196,9 +196,9 @@ void Slider::redraw()
     _aguix->DrawLine( win, p[1].x, p[1].y, p[2].x, p[2].y );
     
     if ( getHasFocus() == true ) {
-      _aguix->setFG( 2 );
+      _aguix->setFG( _aguix->getFaceCol_3d_bright() );
     } else {
-      _aguix->setFG( 1 );
+      _aguix->setFG( _aguix->getFaceCol_3d_dark() );
     }
     p[0].x = 1;
     p[0].y = _h - 1;
@@ -251,7 +251,7 @@ void Slider::redraw()
       _aguix->drawBorder( win, ( bar_dir == 1 ) ? true : false, tx, ty,  ( vertical == true ) ? tw : th, ( vertical == true ) ? tw : th, 0 );
 
       // Left/Up-Arrow
-      _aguix->setFG( 1 );
+      _aguix->setFG( _aguix->getFaceCol_default_fg() );
       _aguix->DrawTriangleFilled( win,
                                   arrow1[0].x, arrow1[0].y,
                                   arrow1[1].x, arrow1[1].y,
@@ -270,7 +270,7 @@ void Slider::redraw()
                              tw, th );
   }
 
-  _aguix->setFG( 1 );
+  _aguix->setFG( _aguix->getFaceCol_3d_dark() );
   if ( m_show_arrow_buttons ) {
       p[0].x = ( vertical == true ) ? tx + tw - 1: tx + th;
       p[0].y = ( vertical == true ) ? ty + tw : ty + th - 1;
@@ -288,7 +288,7 @@ void Slider::redraw()
       _aguix->DrawLine( win, p[0].x, p[0].y, p[1].x, p[1].y );
       _aguix->DrawLine( win, p[1].x, p[1].y, p[2].x, p[2].y );
   }
-  _aguix->setFG( 2 );
+  _aguix->setFG( _aguix->getFaceCol_3d_bright() );
   if ( m_show_arrow_buttons ) {
       p[0].x = ( vertical == true ) ? tx : tx + th;
       p[0].y = ( vertical == true ) ? ty + tw : ty;
@@ -314,7 +314,7 @@ void Slider::redraw()
       _aguix->drawBorder( win, ( bar_dir == 2 ) ? true : false, p[0].x, p[0].y, ( vertical == true ) ? tw : th, ( vertical == true ) ? tw : th, 0 );
 
       // Right-Arrow
-      _aguix->setFG( 1 );
+      _aguix->setFG( _aguix->getFaceCol_default_fg() );
       _aguix->DrawTriangleFilled( win,
                                   arrow2[0].x, arrow2[0].y,
                                   arrow2[1].x, arrow2[1].y,
