@@ -982,9 +982,9 @@ void TextView::selectAll()
     setSelectionEnd( ts.getNrOfUnwrappedLines() - 1, (int)line_str.size() );
 }
 
-void TextView::sizeChanged( int width, int height )
+void TextView::sizeChanged( int width, int height, bool explicit_resize )
 {
-    AWindow::sizeChanged( width, height );
+    AWindow::sizeChanged( width, height, explicit_resize );
     //TODO it would be better to send a X expose message to prevent
     //  additional redraws if X already send such a message
     redraw();
