@@ -536,7 +536,7 @@ namespace AGUIXUtils
                  ch == '/' ) {
                 res += ch;
             } else {
-                res += formatStringToString( "%%%02x", ch );
+                res += formatStringToString( "%%%02x", (unsigned char)ch );
             }
         }
 
