@@ -106,6 +106,8 @@ namespace AGUIXUtils
 
     bool ends_with( const std::string &str,
                     const std::string &suffix );
+    bool contains( const std::string &str,
+                   const std::string &infix );
 
     bool char_in_string( const char ch,
                          const std::string &str );
