@@ -76,7 +76,7 @@ int DNDAction::run( WPUContext *wpu, ActionMessage *msg )
 
 const char *DNDAction::getDescription()
 {
-  return catalog.getLocaleCom(0);
+  return catalog.getLocale(1241);
 }
 
 void DNDAction::normalmodedndaction( ActionMessage *am )
@@ -209,7 +209,7 @@ int DoubleClickAction::run( WPUContext *wpu, ActionMessage *msg )
 
 const char *DoubleClickAction::getDescription()
 {
-  return catalog.getLocaleCom(1);
+  return catalog.getLocale(1242);
 }
 
 void DoubleClickAction::normalmodeddaction( ActionMessage *am )
@@ -368,7 +368,7 @@ int ShowAction::run( WPUContext *wpu, ActionMessage *msg )
 
 const char *ShowAction::getDescription()
 {
-  return catalog.getLocaleCom(2);
+  return catalog.getLocale(1243);
 }
 
 void ShowAction::normalmodeshow( ActionMessage *am )
@@ -527,7 +527,7 @@ int RawShowAction::run( WPUContext *wpu, ActionMessage *msg )
 
 const char *RawShowAction::getDescription()
 {
-  return catalog.getLocaleCom(3);
+  return catalog.getLocale(1244);
 }
 
 void RawShowAction::normalmoderawshow( ActionMessage *am )
@@ -689,7 +689,7 @@ int UserAction::run( WPUContext *wpu, ActionMessage *msg )
 
 const char *UserAction::getDescription()
 {
-  return catalog.getLocaleCom(4);
+  return catalog.getLocale(1245);
 }
 
 void UserAction::normalmodeuseraction( ActionMessage *am )
@@ -808,8 +808,8 @@ int UserAction::configure()
   int endmode=-1;
   char *tstr;
   
-  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(4))+1);
-  sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(4));
+  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(getDescription())+1);
+  sprintf(tstr,catalog.getLocale(293),getDescription());
   win =new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
@@ -993,7 +993,7 @@ bool ChangeHiddenFlag::save(Datei *fh)
 
 const char *ChangeHiddenFlag::getDescription()
 {
-  return catalog.getLocaleCom(7);
+  return catalog.getLocale(1248);
 }
 
 int ChangeHiddenFlag::configure()
@@ -1005,8 +1005,8 @@ int ChangeHiddenFlag::configure()
   int endmode=-1;
   char *tstr;
   
-  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(7))+1);
-  sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(7));
+  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(getDescription())+1);
+  sprintf(tstr,catalog.getLocale(293),getDescription());
   win=new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
