@@ -136,7 +136,7 @@ ChangeLayoutOp::save( Datei *fh )
 const char *
 ChangeLayoutOp::getDescription()
 {
-    return catalog.getLocaleCom( 57 );
+    return catalog.getLocale( 1298 );
 }
 
 static struct {
