@@ -398,7 +398,7 @@ int ChModOwnCore::requestNewMode( const FileEntry &fe, changemod_info_t *return_
     char *tstr;
     
     tmode = ( ( fe.isLink == true ) && ( fe.isCorrupt == false ) ) ? fe.dmode() : fe.mode();
-    win = new AWindow( m_aguix, 10, 10, 10, 10, catalog.getLocaleCom( 38 ), AWindow::AWINDOW_DIALOG );
+    win = new AWindow( m_aguix, 10, 10, 10, 10, catalog.getLocale( 1279 ), AWindow::AWINDOW_DIALOG );
     win->create();
     
     AContainer *ac1 = win->setContainer( new AContainer( win, 1, 4 ), true );
@@ -674,7 +674,7 @@ int ChModOwnCore::requestNewOwner( const FileEntry &fe, uid_t *return_owner, gid
 
     ttw = tth = 10;
     ttx = tty = 5;
-    win = new AWindow( m_aguix, 10, 10, ttw, tth, catalog.getLocaleCom( 43 ), AWindow::AWINDOW_DIALOG );
+    win = new AWindow( m_aguix, 10, 10, ttw, tth, catalog.getLocale( 1284 ), AWindow::AWINDOW_DIALOG );
     win->create();
     tstr = (char*)_allocsafe( strlen( catalog.getLocale( 448 ) ) + strlen( fe.fullname ) + 1 );
     sprintf( tstr, catalog.getLocale( 448 ), fe.fullname );
