@@ -105,7 +105,7 @@ ChOwnOp::save( Datei *fh )
 const char *
 ChOwnOp::getDescription()
 {
-  return catalog.getLocaleCom( 43 );
+  return catalog.getLocale( 1284 );
 }
 
 int
@@ -189,8 +189,8 @@ ChOwnOp::doconfigure( int mode )
                    AContainer::ACONT_MAXH +
                    AContainer::ACONT_MAXW;
   
-  tstr = (char*)_allocsafe( strlen( catalog.getLocale( 293 ) ) + strlen( catalog.getLocaleCom( 43 ) ) + 1 );
-  sprintf( tstr, catalog.getLocale( 293 ), catalog.getLocaleCom( 43 ) );
+  tstr = (char*)_allocsafe( strlen( catalog.getLocale( 293 ) ) + strlen( getDescription() ) + 1 );
+  sprintf( tstr, catalog.getLocale( 293 ), getDescription() );
   win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe( tstr );
@@ -199,7 +199,7 @@ ChOwnOp::doconfigure( int mode )
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
-  ac1->add( new Text( aguix, 0, 0, catalog.getLocaleCom( 43 ) ), 0, 0, cincwnr );
+  ac1->add( new Text( aguix, 0, 0, getDescription() ), 0, 0, cincwnr );
 
   ofcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, ( onfiles == true ) ? 1 : 0,
                                                     catalog.getLocale( 295 ), LABEL_RIGHT, 0 ), 0, 1, cincwnr );
