@@ -103,7 +103,7 @@ bool ChTimeOp::save( Datei *fh )
 
 const char * ChTimeOp::getDescription()
 {
-    return catalog.getLocaleCom( 63 );
+    return catalog.getLocale( 1304 );
 }
 
 int ChTimeOp::vdm_chtime( ActionMessage *am )
@@ -191,7 +191,7 @@ int ChTimeOp::doconfigure( int mode )
     ac1->setMinSpace( 5 );
     ac1->setMaxSpace( 5 );
 
-    ac1->add( new Text( aguix, 0, 0, catalog.getLocaleCom( 38 ) ), 0, 0, AContainer::CO_INCWNR );
+    ac1->add( new Text( aguix, 0, 0, getDescription() ), 0, 0, AContainer::CO_INCWNR );
 
     ofcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( m_onfiles == true ) ? 1 : 0,
                                                       catalog.getLocale( 295 ), LABEL_RIGHT, 0 ), 0, 1, AContainer::CO_INCWNR );
