@@ -1094,7 +1094,7 @@ const char *CondParser::requestFlag()
   const char *returnstr;
   int i, trow, nr;
   
-  win = new AWindow( aguix, 10, 10, 10, 10, 0, catalog.getLocale( 338 ), AWindow::AWINDOW_DIALOG );
+  win = new AWindow( aguix, 10, 10, 10, 10, catalog.getLocale( 338 ), AWindow::AWINDOW_DIALOG );
   win->create();
 
   AContainer *ac1 = win->setContainer( new AContainer( win, 1, 3 ), true );
@@ -1139,15 +1139,11 @@ const char *CondParser::requestFlag()
                                                 0,
                                                 0,
                                                 catalog.getLocale( 11 ),
-                                                1,
-                                                0,
                                                 0 ), 0, 0, AContainer::CO_FIX );
   Button *cancelb = (Button*)ac1_1->add( new Button( aguix,
 						     0,
 						     0,
 						     catalog.getLocale( 8 ),
-						     1,
-						     0,
 						     0 ), 1, 0, AContainer::CO_FIX );
 
   win->setDoTabCycling( true );
@@ -1174,7 +1170,7 @@ const char *CondParser::requestFlag()
     // ok
     trow = lv->getActiveRow();
     if ( lv->isValidRow( trow ) == true ) {
-      i = lv->getData( trow );
+      i = lv->getData( trow, 0 );
       returnstr = flags[i].flag;
     }
   }
