@@ -1,6 +1,6 @@
 /* configtokens.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2003-2018 Ralf Hoffmann.
+ * Copyright (C) 2003-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -443,6 +443,10 @@ struct mytoken tokenlist[]={
   { EXTERNALVDIROP_WCP, "externalvdirop" },
   { VDIR_PRESERVE_DIR_STRUCTURE_WCP, "vdirpreservedirstructure" },
   { OPENTABMENUOP_WCP, "opentabmenuop" },
+  { INITIALTAB_WCP, "initialtab" },
+  { SHOWBYTIME_WCP, "showbytime" },
+  { SHOWBYFILTER_WCP, "showbyfilter" },
+  { EXTENSION_WCP, "extension" },
 };
 
 ArrayList *tokenlist_sorted = NULL;
