@@ -114,7 +114,7 @@ CopyOpWin::open()
   window = new AWindow( aguix,
 			10, 10,
 			w, h,
-			( move == true ) ? catalog.getLocale( 299 ) : catalog.getLocaleCom( 8 ),
+			( move == true ) ? catalog.getLocale( 299 ) : catalog.getLocale( 1249 ),
                         AWindow::AWINDOW_NORMAL );
   window->create();
   tx=5;
@@ -525,17 +525,17 @@ CopyOpWin::redraw( bool skip_message_handling )
     newglob_percent = (int)( rate * 100.0 );
     if ( newglob_percent != glob_percent ) {
         glob_percent = newglob_percent;
-        tstr3 = (char*)_allocsafe( strlen( ( move == true ) ? catalog.getLocale( 299 ) : catalog.getLocaleCom( 8 ) ) +
+        tstr3 = (char*)_allocsafe( strlen( ( move == true ) ? catalog.getLocale( 299 ) : catalog.getLocale( 1249 ) ) +
                                    strlen( " ( %)" ) + 
                                    A_BYTESFORNUMBER( glob_percent ) +
                                    1 );
         if ( ( glob_percent > 0 ) && ( glob_percent <= 100 ) ) {
             sprintf( tstr3, "%s (%d %%)",
-                     ( move == true ) ? catalog.getLocale( 299 ) : catalog.getLocaleCom( 8 ),
+                     ( move == true ) ? catalog.getLocale( 299 ) : catalog.getLocale( 1249 ),
                      glob_percent );
         } else {
             sprintf( tstr3, "%s",
-                     ( move == true ) ? catalog.getLocale( 299 ) : catalog.getLocaleCom( 8 ) );
+                     ( move == true ) ? catalog.getLocale( 299 ) : catalog.getLocale( 1249 ) );
         }
         window->setTitle( tstr3 );
         _freesafe( tstr3 );
