@@ -1,6 +1,6 @@
 /* deeppathstore.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2012-2015 Ralf Hoffmann.
+ * Copyright (C) 2012-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -27,9 +27,9 @@ DeepPathStore::DeepPathStore()
 {
 }
 
-void DeepPathStore::storePath( const std::string &path, time_t ts, DeepPathNode::node_change_t *changed )
+void DeepPathStore::storePath( const std::string &path, time_t ts, DeepPathNode::node_change_t *changed, enum dps_ts_update ts_update  )
 {
-    storePath( m_root, path, ts, 0, changed );
+    storePath( m_root, path, ts, 0, changed, ts_update );
 }
 
 static void push_leafs( const DeepPathNode &node,
@@ -63,18 +63,48 @@ std::list< std::pair< std::string, time_t > > DeepPathStore::getPaths()
     return l;
 }
 
+static void walk_leafs( const DeepPathNode &node,
+                        std::function< void( const std::string &, time_t ) > cb,
+                        const std::string &prefix )
+{
+    std::string new_prefix( prefix );
+
+    new_prefix += node.get_name();
+
+    if ( node.get_children().empty() ) {
+        if ( ! new_prefix.empty() ) {
+            cb( new_prefix, node.get_ts() );
+        }
+    } else {
+        for ( std::list< DeepPathNode >::const_iterator it1 = node.get_children().begin();
+              it1 != node.get_children().end();
+              it1++ ) {
+            walk_leafs( *it1, cb, new_prefix );
+        }
+    }
+}
+
+void DeepPathStore::walkPaths( std::function< void( const std::string &, time_t ) > cb )
+{
+    walk_leafs( m_root, cb, "" );
+}
+
 void DeepPathStore::storePath( DeepPathNode &node,
                                const std::string &path,
                                time_t ts,
                                std::string::size_type start_pos,
-                               DeepPathNode::node_change_t *changed )
+                               DeepPathNode::node_change_t *changed,
+                               enum dps_ts_update ts_update  )
 {
     if ( start_pos == std::string::npos ) {
         if ( node.get_ts() != ts ) {
-            node.set_ts( ts );
-            if ( changed ) {
-                if ( *changed == DeepPathNode::NODE_UNCHANGED ) {
-                    *changed = DeepPathNode::NODE_UPDATED;
+            if ( ts_update == DPS_TS_UPDATE_ALWAYS ||
+                 ( ts_update == DPS_TS_UPDATE_NONZERO && ts != 0 ) ) {
+                node.set_ts( ts );
+                if ( changed ) {
+                    if ( *changed == DeepPathNode::NODE_UNCHANGED ) {
+                        *changed = DeepPathNode::NODE_UPDATED;
+                    }
                 }
             }
         }
@@ -101,10 +131,10 @@ void DeepPathStore::storePath( DeepPathNode &node,
 
     if ( ! ( path[start_pos] == '/' && basename_length == 1 ) ) {
         storePath( node.lookup_or_insert( basename, ts, changed ),
-                   path, ts, slash, changed );
+                   path, ts, slash, changed, ts_update );
     } else {
         if ( slash != std::string::npos ) {
-            storePath( node, path, ts, slash, changed );
+            storePath( node, path, ts, slash, changed, ts_update );
         }
     }
 }
