@@ -46,7 +46,7 @@ DirBookmarkUI::DirBookmarkUI( AGUIX &aguix, BookmarkDBProxy &data  ) : m_aguix(
     m_win = std::unique_ptr<AWindow>( new AWindow( &m_aguix,
                                                    0, 0,
                                                    400, 400,
-                                                   catalog.getLocaleCom( 51 ) ) );
+                                                   catalog.getLocale( 1292 ) ) );
     m_win->create();
 
     m_co1 = m_win->setContainer( new AContainer( m_win.get(), 1, 5 ), true );
@@ -412,7 +412,7 @@ int DirBookmarkUI::mainLoop()
                   it1++, row-- ) {
                 if ( row == 0 ) {
                     m_selected_entry = std::unique_ptr<BookmarkDBEntry>( new BookmarkDBEntry( *it1 ) );
-                    pdb.pushAccess( m_filtered_data->getInfixFilter(), it1->getName() );
+                    pdb.pushAccess( m_filtered_data->getInfixFilter(), it1->getName(), time( NULL ) );
                 }
             }
         }
@@ -599,7 +599,8 @@ void DirBookmarkUI::highlightBestHit( class PrefixDB &pdb )
 {
     if ( m_filtered_data->getInfixFilter().empty() ) return;
 
-    std::string best_hit = pdb.getBestHit( m_filtered_data->getInfixFilter() );
+    time_t t1;
+    std::string best_hit = pdb.getBestHit( m_filtered_data->getInfixFilter(), t1 );
 
     if ( best_hit.empty() ) return;
 
