@@ -505,7 +505,7 @@ DirCompareOp::run( WPUContext *wpu, ActionMessage *msg )
 const char *
 DirCompareOp::getDescription()
 {
-    return catalog.getLocaleCom( 66 );
+    return catalog.getLocale( 1307 );
 }
 
 int
