@@ -191,7 +191,7 @@ int EnterDirOp::run( WPUContext *wpu, ActionMessage *msg )
 
 const char *EnterDirOp::getDescription()
 {
-    return catalog.getLocaleCom( 18 );
+    return catalog.getLocale( 1259 );
 }
 
 int EnterDirOp::configure()
@@ -212,8 +212,8 @@ int EnterDirOp::configure()
         AContainer::ACONT_MAXW;
   
     tstr = (char*)_allocsafe( strlen( catalog.getLocale( 293 ) ) +
-                              strlen( catalog.getLocaleCom( 18 ) ) + 1 );
-    sprintf( tstr, catalog.getLocale( 293 ), catalog.getLocaleCom( 18 ) );
+                              strlen( getDescription() ) + 1 );
+    sprintf( tstr, catalog.getLocale( 293 ), getDescription() );
     win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
     win->create();
     _freesafe( tstr );
