@@ -1,6 +1,6 @@
 /* execlass.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2002-2013 Ralf Hoffmann.
+ * Copyright (C) 2002-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -27,6 +27,8 @@
 #include "wconfig.h"
 #include "worker.h"
 #include "pdatei.h"
+#include <fstream>
+#include <sstream>
 
 /* THREADSAFE */
 ExeClass::ExeClass( execlass_execute_t exetype, Worker *w )
@@ -812,3 +814,20 @@ int ExeClass::readErrorOutput( std::string &return_str, int maxsize )
   }
   return 0;
 }
+
+int ExeClass::readOutput( std::string &return_str )
+{
+    if ( ! tmpoutput ) return -EINVAL;
+
+    std::ifstream ifile( tmpoutput );
+
+    if ( ! ifile.is_open() ) return -ENOENT;
+
+    std::stringstream buffer;
+
+    buffer << ifile.rdbuf();
+
+    return_str = buffer.str();
+
+    return 0;
+}
