@@ -186,7 +186,7 @@ ExternalVDirOp::save(Datei *fh)
 const char *
 ExternalVDirOp::getDescription()
 {
-    return catalog.getLocaleCom( 68 );
+    return catalog.getLocale( 1309 );
 }
 
 int
