@@ -579,7 +579,7 @@ void FileEntry::setCustomColors( const int fg[4], const int bg[4] )
     m_colors.setCustomColors( fg, bg );
 }
 
-const FileEntryCustomColor &FileEntry::getCustomColor() const throw ( int )
+const FileEntryCustomColor &FileEntry::getCustomColor() const
 {
     return m_colors.getCustomColor();
 }
@@ -789,7 +789,7 @@ void FileEntry::setMatchingLabels( const std::list<std::string> &labels )
     }
 }
 
-const std::list<std::string> &FileEntry::getMatchingLabels() const throw( int )
+const std::list<std::string> &FileEntry::getMatchingLabels() const
 {
     if ( m_bookmark_info == NULL ) throw( 1 );
     if ( m_bookmark_info->m_matching_labels == NULL ) throw( 1 );
