@@ -37,6 +37,7 @@
 #include "wconfig.h"
 #include "listermode.h"
 #include "virtualdirmode.hh"
+#include "pdatei.h"
 
 FileViewerBG::FileViewerBG( Worker *worker ) : win( NULL ),
                                                m_wrap_mode( false ),
@@ -90,7 +91,7 @@ void FileViewerBG::view( const std::list<std::string> &filelist,
     std::list<std::string>::const_iterator it1;
     int w, h, sw, sh;
     
-    win = new AWindow( aguix, 10, 10, 10, 10, catalog.getLocaleCom( 49 ) );
+    win = new AWindow( aguix, 10, 10, 10, 10, catalog.getLocale( 1290 ) );
     win->create();
     /*  if ( aguix->getTransientWindow() != NULL ) {
         win->setTransientForAWindow( aguix->getTransientWindow() );
@@ -443,14 +444,8 @@ int FileViewerBG::buildTextView( const std::string &filename,
     loff_t file_length = 0;
     int initial_size = ( m_wrap_mode == true ) ? ( 512 * 1024 ) : ( 2 * 1024 * 1024 );
     bool continue_viewing = true;
-  
-    if ( fse.isReg( true ) == true ) {
-        if ( fse.isLink() == false ) {
-            file_length = fse.stat_size();
-        } else {
-            file_length = fse.stat_dest_size();
-        }
-    }
+
+    file_length = PDatei::getFileSize( filename );
 
     if ( file_length > initial_size ) {
         std::string l1, l2;
