@@ -1,6 +1,6 @@
 /* flagreplacer.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006,2011-2013 Ralf Hoffmann.
+ * Copyright (C) 2006-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -209,7 +209,7 @@ std::string FlagReplacer::requestFlag( const FlagHelp &flags )
   std::string chosen_flag;
   int trow;
   
-  win = new AWindow( aguix, 10, 10, 10, 10, 0, catalog.getLocale( 338 ), AWindow::AWINDOW_DIALOG );
+  win = new AWindow( aguix, 10, 10, 10, 10, catalog.getLocale( 338 ), AWindow::AWINDOW_DIALOG );
   win->create();
 
   AContainer *ac1 = win->setContainer( new AContainer( win, 1, 3 ), true );
@@ -249,15 +249,11 @@ std::string FlagReplacer::requestFlag( const FlagHelp &flags )
                                                 0,
                                                 0,
                                                 catalog.getLocale( 11 ),
-                                                1,
-                                                0,
                                                 0 ), 0, 0, AContainer::CO_FIX );
   Button *cb = (Button*)ac1_2->add( new Button( aguix,
 						0,
 						0,
 						catalog.getLocale( 8 ),
-						1,
-						0,
 						0 ), 1, 0, AContainer::CO_FIX );
   win->setDoTabCycling( true );
   win->contMaximize( true );
