@@ -172,7 +172,7 @@ GoFTPOp::save(Datei *fh)
 const char *
 GoFTPOp::getDescription()
 {
-  return catalog.getLocaleCom( 48 );
+  return catalog.getLocale( 1289 );
 }
 
 int
@@ -207,8 +207,8 @@ GoFTPOp::doconfigure(int mode)
   
   module_list = getAvailModules();
 
-  tstr = (char*)_allocsafe( strlen( catalog.getLocale( 293 ) ) + strlen( catalog.getLocaleCom( 48 ) ) + 1 );
-  sprintf( tstr, catalog.getLocale( 293 ), catalog.getLocaleCom( 48 ) );
+  tstr = (char*)_allocsafe( strlen( catalog.getLocale( 293 ) ) + strlen( getDescription() ) + 1 );
+  sprintf( tstr, catalog.getLocale( 293 ), getDescription() );
   win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe( tstr );
