@@ -185,7 +185,12 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_KP_Add,0);
   key->setMod( 0, 0 );
   b1->setDoubleKeys( keylist );
-  fp=new SelectAllOp();
+  {
+      auto tfp = new ScriptOp();
+      tfp->setType( ScriptOp::SCRIPT_EVALCOMMAND );
+      tfp->setCommandStr( "selectall" );
+      fp = tfp;
+  }
   nc->addElement(fp);
   b1->setComs(nc);
   delete fp;
@@ -198,7 +203,12 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_KP_Subtract,0);
   key->setMod( 0, 0 );
   b1->setDoubleKeys( keylist );
-  fp=new SelectNoneOp();
+  {
+      auto tfp = new ScriptOp();
+      tfp->setType( ScriptOp::SCRIPT_EVALCOMMAND );
+      tfp->setCommandStr( "selectnone" );
+      fp = tfp;
+  }
   nc->addElement(fp);
   b1->setComs(nc);
   delete fp;
@@ -211,7 +221,12 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_KP_Multiply,0);
   key->setMod( 0, 0 );
   b1->setDoubleKeys( keylist );
-  fp=new InvertAllOp();
+  {
+      auto tfp = new ScriptOp();
+      tfp->setType( ScriptOp::SCRIPT_EVALCOMMAND );
+      tfp->setCommandStr( "invertall" );
+      fp = tfp;
+  }
   nc->addElement(fp);
   b1->setComs(nc);
   delete fp;
@@ -597,7 +612,13 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_Up,0);
   key->setMod( 0, 0 );
   h1->setDoubleKeys( keylist );
-  fp=new RowUp();
+
+  {
+      auto tfp = new ScriptOp();
+      tfp->setType( ScriptOp::SCRIPT_EVALCOMMAND );
+      tfp->setCommandStr( "up" );
+      fp = tfp;
+  }
   nc->addElement(fp);
   h1->setComs(nc);
   delete fp;
@@ -609,7 +630,12 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_Down,0);
   key->setMod( 0, 0 );
   h1->setDoubleKeys( keylist );
-  fp=new RowDown();
+  {
+      auto tfp = new ScriptOp();
+      tfp->setType( ScriptOp::SCRIPT_EVALCOMMAND );
+      tfp->setCommandStr( "down" );
+      fp = tfp;
+  }
   nc->addElement(fp);
   h1->setComs(nc);
   delete fp;
@@ -633,7 +659,12 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_Home,0);
   key->setMod( 0, 0 );
   h1->setDoubleKeys( keylist );
-  fp=new FirstRow();
+  {
+      auto tfp = new ScriptOp();
+      tfp->setType( ScriptOp::SCRIPT_EVALCOMMAND );
+      tfp->setCommandStr( "first" );
+      fp = tfp;
+  }
   nc->addElement(fp);
   h1->setComs(nc);
   delete fp;
@@ -645,7 +676,12 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_End,0);
   key->setMod( 0, 0 );
   h1->setDoubleKeys( keylist );
-  fp=new LastRow();
+  {
+      auto tfp = new ScriptOp();
+      tfp->setType( ScriptOp::SCRIPT_EVALCOMMAND );
+      tfp->setCommandStr( "last" );
+      fp = tfp;
+  }
   nc->addElement(fp);
   h1->setComs(nc);
   delete fp;
@@ -657,7 +693,12 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_Prior,0);
   key->setMod( 0, 0 );
   h1->setDoubleKeys( keylist );
-  fp=new PageUp();
+  {
+      auto tfp = new ScriptOp();
+      tfp->setType( ScriptOp::SCRIPT_EVALCOMMAND );
+      tfp->setCommandStr( "pageup" );
+      fp = tfp;
+  }
   nc->addElement(fp);
   h1->setComs(nc);
   delete fp;
@@ -669,7 +710,12 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_Next,0);
   key->setMod( 0, 0 );
   h1->setDoubleKeys( keylist );
-  fp=new PageDown();
+  {
+      auto tfp = new ScriptOp();
+      tfp->setType( ScriptOp::SCRIPT_EVALCOMMAND );
+      tfp->setCommandStr( "pagedown" );
+      fp = tfp;
+  }
   nc->addElement(fp);
   h1->setComs(nc);
   delete fp;
@@ -677,11 +723,16 @@ void WConfig::setDefaultConfig()
   nh->addElement(h1);
 
   h1=new WCHotkey();
-  h1->setName("Invert actual entry");
+  h1->setName("Invert current entry");
   key->setKeySym(XK_Insert,0);
   key->setMod( 0, 0 );
   h1->setDoubleKeys( keylist );
-  fp=new SelectOp();
+  {
+      auto tfp = new ScriptOp();
+      tfp->setType( ScriptOp::SCRIPT_EVALCOMMAND );
+      tfp->setCommandStr( "selectentry" );
+      fp = tfp;
+  }
   nc->addElement(fp);
   h1->setComs(nc);
   delete fp;
@@ -693,7 +744,12 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_Left,0);
   key->setMod( 0, 0 );
   h1->setDoubleKeys( keylist );
-  fp=new ParentDirOp();
+  {
+      auto tfp = new ScriptOp();
+      tfp->setType( ScriptOp::SCRIPT_EVALCOMMAND );
+      tfp->setCommandStr( "parentdir" );
+      fp = tfp;
+  }
   nc->addElement(fp);
   h1->setComs(nc);
   delete fp;
@@ -754,7 +810,12 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_Return,0);
   key->setMod( 0, 0 );
   h1->setDoubleKeys( keylist );
-  fp=new SimDDOp();
+  {
+      auto tfp = new ScriptOp();
+      tfp->setType( ScriptOp::SCRIPT_EVALCOMMAND );
+      tfp->setCommandStr( "simulate_doubleclick" );
+      fp = tfp;
+  }
   nc->addElement(fp);
   h1->setComs(nc);
   delete fp;
