@@ -1,6 +1,6 @@
 /* lister.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2014 Ralf Hoffmann.
+ * Copyright (C) 2001-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -30,11 +30,12 @@
 #include <aguix/choosebutton.h>
 #include <aguix/fieldlistview.h>
 #include <aguix/awindow.h>
+#include <aguix/icons.hh>
 #include "listermode.h"
 #include "datei.h"
 #include "nmfilter.hh"
 
-Lister::Lister(Worker *tparent)
+Lister::Lister( Worker *tparent, int side )
 {
   this->parent = tparent;
   aguix = parent->getAGUIX();
@@ -46,10 +47,28 @@ Lister::Lister(Worker *tparent)
   m_cont->setMaxSpace( 0 );
   m_mode_cont = NULL;
 
-  lvb = (Button*)m_cont->add( new Button( aguix, 0, 0,
-                                          a_max( win->getWidth(), 50 ), "", "", 1, 1, 0, 0, 1 ),
-                              0, 0, AContainer::CO_INCW );
-  m_cont->setMinWidth( 50, 0, 0 );
+  m_button_cont = m_cont->add( new AContainer( win, 2, 1 ),
+                                0, 0 );
+  m_button_cont->setBorderWidth( 0 );
+  m_button_cont->setMinSpace( 0 );
+  m_button_cont->setMaxSpace( 0 );
+
+  lvb = m_button_cont->addWidget( new Button( aguix, 0, 0,
+                                              a_max( win->getWidth(), 50 ), "", "", 1, 1, 0, 0, 1 ),
+                                  side == 0 ? 0 : 1, 0, AContainer::CO_INCW );
+  m_configure_b = m_button_cont->addWidget( new Button( aguix, 0, 0, "", 1, 0, 2 ),
+                                            side == 0 ? 1 : 0, 0, AContainer::CO_FIX );
+  m_configure_b->resize( m_configure_b->getHeight(),
+                         m_configure_b->getHeight() );
+  m_configure_b->setAcceptFocus( false );
+
+  m_button_cont->readLimits();
+
+  m_configure_b->setBubbleHelpText( catalog.getLocale( 998 ) );
+  m_configure_b->setIcon( aguix_icon_pref, aguix_icon_pref_len,
+                          Button::ICON_LEFT );
+
+  m_button_cont->setMinWidth( 50, side == 0 ? 0 : 1, 0 );
   lvb->setAcceptFocus( false );
 
   lvb->setBubbleHelpText( catalog.getLocale( 1124 ) );
@@ -77,6 +96,7 @@ Lister::~Lister()
   }
   delete [] modes;
   delete lvb;
+  delete m_configure_b;
   delete m_cont;
 }
 
@@ -104,6 +124,12 @@ void Lister::messageHandler(AGMessage *msg)
               lastlvbclick.tv_usec = acttime.tv_usec;
             }
           }
+        } else if ( msg->button.button == m_configure_b ) {
+            makeActive();
+
+            if ( activemode != NULL ) {
+                activemode->configure();
+            }
         }
         break;
       case AG_MOUSECLICKED:
@@ -175,6 +201,8 @@ void Lister::setFocus(bool state)
   lvb->setBG(0,bg);
   lvb->setFG(1,fg);
   lvb->setBG(1,bg);
+  m_configure_b->setFG( 0, fg );
+  m_configure_b->setBG( 0, bg );
 }
 
 bool Lister::getFocus()
@@ -567,8 +595,12 @@ void  Lister::relayout()
   lvb->setFG(1,fg);
   lvb->setBG(1,bg);
   lvb->resize( lvb->getWidth(), aguix->getCharHeight() + 4 );
-  m_cont->setMinHeight( lvb->getHeight(), 0, 0 );
-  m_cont->setMaxHeight( lvb->getHeight(), 0, 0 );
+  m_configure_b->resize( aguix->getCharHeight() + 4,
+                         aguix->getCharHeight() + 4 );
+  m_configure_b->setFG( 0, fg );
+  m_configure_b->setBG( 0, bg );
+  m_button_cont->readLimits();
+  m_button_cont->setMinWidth( 50, getSide() == 0 ? 0 : 1, 0 );
   win->updateCont();
 
   if(activemode!=NULL) activemode->relayout();
