@@ -1,6 +1,6 @@
 /* listermode.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2017 Ralf Hoffmann.
+ * Copyright (C) 2001-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -30,6 +30,8 @@
 #include "nmspecialsourceext.hh"
 #include <map>
 #include <functional>
+#include "functionproto.h"
+#include "worker_types.h"
 
 class ArgClass;
 class Datei;
@@ -70,9 +72,13 @@ public:
     virtual void runCommand( const std::string &command );
     virtual void runCommand( const std::string &command, const std::list< RefCount< ArgClass > > &args );
     virtual void registerCommand( const std::string &command,
-                                  std::function< void (void) > callback );
+                                  std::function< void (void) > callback,
+                                  const std::string &description = "",
+                                  FunctionProto::command_categories_t category = FunctionProto::CAT_SCRIPTING  );
     virtual void registerCommand( const std::string &command,
-                                  const std::function< void ( const std::list< RefCount< ArgClass > > ) > callback );
+                                  const std::function< void ( const std::list< RefCount< ArgClass > > ) > callback,
+                                  const std::string &description = "",
+                                  FunctionProto::command_categories_t category = FunctionProto::CAT_SCRIPTING );
     virtual void runCommandWithStrArgs( const std::string &command_str );
 
     virtual bool pathsChanged( const std::set< std::string > changed_paths );
@@ -94,7 +100,8 @@ public:
 
     virtual void not_supported();
 
-    virtual std::list< std::string > getListOfCommandsWithoutArgs();
+    virtual std::list< WorkerTypes::reg_command_info_t > getListOfCommandsWithoutArgs() const;
+    virtual WorkerTypes::reg_command_info_t getCommandInfo( const std::string &command ) const;
 
     virtual void finalizeBGOps();
 protected:
@@ -106,6 +113,8 @@ protected:
 private:
     std::map< std::string, std::function< void( void ) > > m_commands;
     std::map< std::string, std::function< void ( const std::list< RefCount< ArgClass > > ) > > m_commands_with_args;
+    std::map< std::string, std::tuple< std::string,
+                                       FunctionProto::command_categories_t > > m_command_info;
 };
 
 #endif
