@@ -1,6 +1,6 @@
 /* magic_db.cc
  * This file is part of Worker, a file manager for UN*X/X11.
- * Copyright (C) 2008,2010 Ralf Hoffmann.
+ * Copyright (C) 2008-2013 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -65,7 +65,7 @@ void MagicDB::fini()
     m_lock.unlock();
 }
 
-std::string MagicDB::getInfo( const char *filename, bool decompress )
+std::string MagicDB::getInfo( const char *filename, bool decompress, bool use_mime )
 {
 #ifdef HAVE_LIBMAGIC
     m_lock.lock();
@@ -77,10 +77,12 @@ std::string MagicDB::getInfo( const char *filename, bool decompress )
 
     std::string res2;
     const char *res;
+    int magic_flags = MAGIC_SYMLINK;
 
-    magic_setflags( m_magic_cookie,
-		    ( ( decompress == true ) ? MAGIC_COMPRESS : MAGIC_NONE ) |
-		    MAGIC_SYMLINK );
+    if ( decompress == true ) magic_flags |= MAGIC_COMPRESS;
+    if ( use_mime == true ) magic_flags |= MAGIC_MIME;
+
+    magic_setflags( m_magic_cookie, magic_flags );
     res = magic_file( m_magic_cookie, filename );
     if ( res != NULL ) {
         res2 = res;
@@ -93,12 +95,12 @@ std::string MagicDB::getInfo( const char *filename, bool decompress )
 #endif
 }
 
-std::string MagicDB::getInfo( const std::string &filename, bool decompress )
+std::string MagicDB::getInfo( const std::string &filename, bool decompress, bool use_mime )
 {
-    return getInfo( filename.c_str(), decompress );
+    return getInfo( filename.c_str(), decompress, use_mime );
 }
 
-std::string MagicDB::getInfo( const void *buffer, size_t len, bool decompress )
+std::string MagicDB::getInfo( const void *buffer, size_t len, bool decompress, bool use_mime )
 {
 #ifdef HAVE_LIBMAGIC
     m_lock.lock();
@@ -110,8 +112,12 @@ std::string MagicDB::getInfo( const void *buffer, size_t len, bool decompress )
 
     std::string res2;
     const char *res;
+    int magic_flags = MAGIC_NONE;
+
+    if ( decompress == true ) magic_flags |= MAGIC_COMPRESS;
+    if ( use_mime == true ) magic_flags |= MAGIC_MIME;
     
-    magic_setflags( m_magic_cookie, ( decompress == true ) ? MAGIC_COMPRESS : MAGIC_NONE );
+    magic_setflags( m_magic_cookie, magic_flags );
     res = magic_buffer( m_magic_cookie, buffer, len );
     if ( res != NULL ) {
         res2 = res;
