@@ -1,6 +1,6 @@
 /* nmfilter.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2006,2011 Ralf Hoffmann.
+ * Copyright (C) 2001-2006,2011,2013 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -21,7 +21,7 @@
 
 #include "nmfilter.hh"
 #include "configheader.h"
-#include "configparser.tab.h"
+#include "configparser.hh"
 #include "wconfig.h"
 #include "datei.h"
 #include <aguix/lowlevelfunc.h>
@@ -140,39 +140,6 @@ int NM_Filter::load()
   return found_error;
 }
 
-int NM_Filter::loadBin(Datei *fh)
-{
-  int chunksize=fh->getInt();
-  int len;
-  char *str;
-  if(chunksize>=(2*Datei::getIntSize())) {
-    len=fh->getInt();
-    chunksize-=Datei::getIntSize();
-    str=fh->getString(len);
-    if(pattern!=NULL) _freesafe(pattern);
-    pattern=str;
-    chunksize-=len;
-    int check=fh->getInt();
-    switch ( check ) {
-      case 1:
-          setCheck( INCLUDE );
-          break;
-      case 2:
-          setCheck( EXCLUDE );
-          break;
-      default:
-          setCheck( INACTIVE );
-          break;
-    }
-    chunksize-=Datei::getIntSize();
-  }
-  while(chunksize>0) {
-    fh->getUChar();
-    chunksize--;
-  }
-  return 0;
-}
-
 int NM_Filter::save(Datei *fh)
 {
   if ( fh == NULL ) return 1;
