@@ -164,34 +164,5 @@ namespace NWC {
             return buf;
         }
 
-        int make_dirs( const std::string &dirname )
-        {
-            NWC::FSEntry fse( dirname );
-
-            if ( fse.entryExists() ) {
-                if ( fse.isDir( true ) ) {
-                    // nothing to do
-                    return 0;
-                }
-
-                return -EEXIST;
-            }
-
-            std::string parent_dirname = fse.getDirname();
-
-            if ( parent_dirname != "" &&
-                 parent_dirname != "." ) {
-                int res = make_dirs( parent_dirname );
-
-                if ( res != 0 ) {
-                    return res;
-                }
-            }
-
-            int res = worker_mkdir( dirname.c_str(), 0777 );
-
-            return res;
-        }
-
     }
 }
