@@ -343,20 +343,24 @@ namespace NWC {
             return res;
         }
 
-        bool is_prefix_dir( const std::string &path1,
-                            const std::string &path2 )
+        bool is_prefix_dir( const std::string &prefix,
+                            const std::string &path )
         {
-            if ( path1.length() > path2.length() ) return false;
+            if ( prefix.length() > path.length() ) return false;
 
-            if ( path1 == path2 ) return true;
+            if ( prefix == path ) return true;
 
-            if ( ! AGUIXUtils::starts_with( path1, path2 ) ) return false;
+            if ( ! AGUIXUtils::starts_with( path, prefix ) ) return false;
 
-            if ( AGUIXUtils::ends_with( path1, "/" ) ) {
+            // check if prefix ends with a slash in which case nothing
+            // else needs to be checked
+            if ( AGUIXUtils::ends_with( prefix, "/" ) ) {
                 return true;
             }
 
-            if ( path2[ path1.length() ] != '/' ) return false;
+            // if path continues with anything other than a slash, the
+            // prefix won't match
+            if ( path[ prefix.length() ] != '/' ) return false;
 
             return true;
         }
