@@ -1,6 +1,6 @@
 /* nwcentryselectionstate.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2013-2014 Ralf Hoffmann.
+ * Copyright (C) 2013-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -298,6 +298,12 @@ int NWCEntrySelectionState::sortfunction( const NWCEntrySelectionState &e1,
           else if ( fse1->stat_mode() > fse2->stat_mode() ) comp = 1;
           else comp = fse1->getFullname().compare( fse2->getFullname() );
           break;
+      case SORT_EXTENSION:
+          comp = fse1->getExtension().compare( fse2->getExtension() );
+          if ( comp == 0 ) {
+              comp = fse1->getFullname().compare( fse2->getFullname() );
+          }
+          break;
     }
 
     if ( ( mode & SORT_REVERSE ) == SORT_REVERSE ) comp *= -1;
@@ -577,6 +583,9 @@ std::string NWCEntrySelectionState::getStringRepresentation( WorkerTypes::listco
             li = (loff_t)fse->stat_blocks();
             MakeLong2NiceStr( li, res, false );
             break;
+        case WorkerTypes::LISTCOL_EXTENSION:
+            res = fse->getExtension();
+            break;
         default:
             break;
     }
