@@ -149,7 +149,7 @@ OwnOp::save(Datei *fh)
 const char *
 OwnOp::getDescription()
 {
-  return catalog.getLocaleCom(28);
+  return catalog.getLocale(1269);
 }
 
 static bool isCorrectViewProg( const char *str )
@@ -191,8 +191,8 @@ OwnOp::configure()
   req=new Requester(aguix);
   freq = new FileRequester( aguix );
 
-  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(28))+1);
-  sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(28));
+  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(getDescription())+1);
+  sprintf(tstr,catalog.getLocale(293),getDescription());
   win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
