@@ -60,6 +60,7 @@ int PartSpace::readSpace( const char* name )
 
     if ( name == NULL ) return EFAULT;
     if ( worker_stat( name, &buf1 ) != 0 ) return EFAULT;
+    if ( buf1.st_dev == 0 ) return EFAULT;
     name_device = buf1.st_dev;
 
     ct = time( NULL );
@@ -72,23 +73,30 @@ int PartSpace::readSpace( const char* name )
 
     m_data_lock.lock();
     if ( m_space_data.count( name_device  ) > 0 ) {
-        if ( m_space_data[name_device].m_stats_valid ) {
+        switch ( m_space_data[name_device].m_stats_valid ) {
+            case SpaceData::VALID:
+            case SpaceData::PENDING_VALID:
 #ifdef HAVE_STATVFS
-            blocksize = m_space_data[name_device].m_fsstatistic.f_frsize;
-            space = m_space_data[name_device].m_fsstatistic.f_blocks;
-            freespace = m_space_data[name_device].m_fsstatistic.f_bavail;
+                blocksize = m_space_data[name_device].m_fsstatistic.f_frsize;
+                space = m_space_data[name_device].m_fsstatistic.f_blocks;
+                freespace = m_space_data[name_device].m_fsstatistic.f_bavail;
 #elif defined( HAVE_STATFS )
-            blocksize = m_space_data[name_device].m_fsstatistic.f_bsize;
-            space = m_space_data[name_device].m_fsstatistic.f_blocks;
-            freespace = m_space_data[name_device].m_fsstatistic.f_bavail;
+                blocksize = m_space_data[name_device].m_fsstatistic.f_bsize;
+                space = m_space_data[name_device].m_fsstatistic.f_blocks;
+                freespace = m_space_data[name_device].m_fsstatistic.f_bavail;
 #else
-            blocksize = 0;
-            space = 0;
-            freespace = 0;
+                blocksize = 0;
+                space = 0;
+                freespace = 0;
 #endif
-            ret = 0;
-        } else {
-            ret = EAGAIN;
+                ret = 0;
+                break;
+            case SpaceData::UNAVAIL:
+                ret = EFAULT;
+                break;
+            default:
+                ret = EAGAIN;
+                break;
         }
 
         if ( ( ct - m_space_data[name_device].m_last_update ) >= m_info_lifetime ) {
@@ -100,6 +108,11 @@ int PartSpace::readSpace( const char* name )
     }
     if ( do_update == true ) {
         m_space_data[name_device].m_last_update = ct;
+        if ( m_space_data[name_device].m_stats_valid == SpaceData::VALID ) {
+            m_space_data[name_device].m_stats_valid = SpaceData::PENDING_VALID;
+        } else {
+            m_space_data[name_device].m_stats_valid = SpaceData::PENDING_INVALID;
+        }
     }
 
     if ( (int)m_space_data.size() > m_maxsize ) {
@@ -202,9 +215,9 @@ void PartSpace::slavehandler()
 
                 if ( error == 0 ) {
                     m_space_data[name_device].m_fsstatistic = fsstatistic;
-                    m_space_data[name_device].m_stats_valid = true;
+                    m_space_data[name_device].m_stats_valid = SpaceData::VALID;
                 } else {
-                    m_space_data[name_device].m_stats_valid = false;
+                    m_space_data[name_device].m_stats_valid = SpaceData::UNAVAIL;
                 }
 
                 m_data_lock.unlock();
