@@ -1,6 +1,6 @@
 /* prefixdb.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2010 Ralf Hoffmann.
+ * Copyright (C) 2010-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -46,7 +46,7 @@ PrefixDB::~PrefixDB()
 {
 }
 
-std::string PrefixDB::getBestHit( const std::string &prefix )
+std::string PrefixDB::getBestHit( const std::string &prefix, time_t &return_last_use )
 {
     read();
 
@@ -62,43 +62,54 @@ std::string PrefixDB::getBestHit( const std::string &prefix )
 
     // now it1 is the first entry which is not lower than pdb_test
 
+    return_last_use = 0;
     if ( it1 == m_db.end() ) return "";
 
-    // for exact hit consider only this entry
-    if ( it1->getPrefix() == prefix ) return it1->getBestHit();
-
-    // otherwise search all entries for which prefix is a prefix
-
     std::string best_hit;
     float best_hit_count = -1.0;
+    time_t best_last_use = 0;
+
+    // for exact hit consider only this entry
+    if ( it1->getPrefix() == prefix ) {
+        return it1->getBestHit( best_hit_count,
+                                return_last_use );
+    }
+
+    // otherwise search all entries for which prefix is a prefix
 
     for ( ;
-	  it1 != m_db.end();
-	  it1++ ) {
-	if ( it1->getPrefix().compare( 0, prefix.length(), prefix ) == 0 ) {
-	    if ( best_hit_count < 0 ) {
-		best_hit = it1->getBestHit( best_hit_count );
-	    } else {
-		float t1;
-		std::string s1;
-		s1 = it1->getBestHit( t1 );
+          it1 != m_db.end();
+          it1++ ) {
+        if ( it1->getPrefix().compare( 0, prefix.length(), prefix ) == 0 ) {
+            if ( best_hit_count < 0 ) {
+                best_hit = it1->getBestHit( best_hit_count, best_last_use );
+            } else {
+                float t1;
+                std::string s1;
+                time_t t2;
+
+                s1 = it1->getBestHit( t1, t2 );
 		
-		if ( t1 > best_hit_count ) {
-		    best_hit = s1;
-		    best_hit_count = t1;
-		}
-	    }
-	} else {
+                if ( t1 > best_hit_count ) {
+                    best_hit = s1;
+                    best_hit_count = t1;
+                    best_last_use = t2;
+                }
+            }
+        } else {
             // since m_db is sorted we can stop here
             break;
         }
     }
 
+    return_last_use = best_last_use;
+
     return best_hit;
 }
 
 void PrefixDB::pushAccess( const std::string &prefix,
-                           const std::string &value )
+                           const std::string &value,
+                           time_t last_use )
 {
     read();
 
@@ -116,12 +127,12 @@ void PrefixDB::pushAccess( const std::string &prefix,
 
     if ( it1 == m_db.end() ||
          it1->getPrefix() != prefix ) {
-	PrefixDBEntry pe( prefix );
-	pe.storeAccess( value );
-	m_db.push_back( pe );
-	std::sort( m_db.begin(), m_db.end() );
+        PrefixDBEntry pe( prefix );
+        pe.storeAccess( value, last_use );
+        m_db.push_back( pe );
+        std::sort( m_db.begin(), m_db.end() );
     } else {
-	it1->storeAccess( value );
+        it1->storeAccess( value, last_use );
     }
 
     write();
@@ -278,8 +289,8 @@ void PrefixDB::write()
     time_t now = time( NULL );
 
     if ( now >= m_next_aging ) {
-	age();
-	m_next_aging = now + 24 * 60 * 60;
+        age();
+        m_next_aging = now + 24 * 60 * 60;
     }
 
     std::string lockname = m_filename;
@@ -308,7 +319,11 @@ void PrefixDB::write()
         }
 #else
         Datei fh;
-        if ( fh.open( m_filename.c_str(), "w" ) == 0 ) {
+
+        std::string temp_target_file = m_filename;
+        temp_target_file += ".new";
+
+        if ( fh.open( temp_target_file.c_str(), "w" ) == 0 ) {
             fh.configPutPairString( "nextaging", AGUIXUtils::convertToString( m_next_aging ).c_str() );
         
             std::vector< PrefixDBEntry >::iterator it1;
@@ -323,6 +338,12 @@ void PrefixDB::write()
                 fh.configCloseSection();
             }
             fh.close();
+
+            if ( fh.errors() ) {
+                worker_unlink( temp_target_file.c_str() );
+            } else {
+                worker_rename( temp_target_file.c_str(), m_filename.c_str() );
+            }
         }
 #endif
 
@@ -343,3 +364,56 @@ void PrefixDB::age( float factor )
 	it1->age( factor );
     }
 }
+
+std::set< std::string > PrefixDB::getAllStrings()
+{
+    std::set< std::string > strings;
+
+    read();
+
+    for ( auto &dbe : m_db ) {
+        for ( auto &s1 : dbe.getStrings() ) {
+            strings.insert( std::get<0>( s1 ) );
+        }
+    }
+
+    return strings;
+}
+
+std::map< std::string, std::tuple< std::string, float, time_t > > PrefixDB::getAllBestHits()
+{
+    std::map< std::string, std::tuple< std::string, float, time_t > > res;
+
+    read();
+
+    for ( auto &dbe : m_db ) {
+        float f = 1.234;
+        time_t last_use = 0;
+        std::string p = dbe.getBestHit( f, last_use );
+
+        if ( ! p.empty() ) {
+            res[ dbe.getPrefix() ] = std::make_tuple( p, f, last_use );
+        }
+    }
+
+    return res;
+}
+
+void PrefixDB::removeEntry( const std::string &prefix )
+{
+    read();
+
+    auto it = std::find_if( m_db.begin(),
+                            m_db.end(),
+                            [prefix] ( const PrefixDBEntry &e ) {
+                                return e.getPrefix() == prefix;
+                            } );
+
+    if ( it == m_db.end() ) {
+        return;
+    }
+
+    m_db.erase( it );
+
+    write();
+}
