@@ -105,7 +105,7 @@ ReloadOp::save(Datei *fh)
 const char *
 ReloadOp::getDescription()
 {
-  return catalog.getLocaleCom(26);
+  return catalog.getLocale(1267);
 }
 
 void
@@ -171,8 +171,8 @@ ReloadOp::configure()
                    AContainer::ACONT_MAXH +
                    AContainer::ACONT_MAXW;
   
-  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(26))+1);
-  sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(26));
+  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(getDescription())+1);
+  sprintf(tstr,catalog.getLocale(293),getDescription());
   win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
