@@ -81,7 +81,7 @@ RenameOp::run( WPUContext *wpu, ActionMessage *msg )
 const char *
 RenameOp::getDescription()
 {
-  return catalog.getLocaleCom(29);
+  return catalog.getLocale(1270);
 }
 
 int
