@@ -388,7 +388,7 @@ ScriptOp::run( WPUContext *wpu, ActionMessage *msg )
 
             if ( wpu->parse( m_command_str.c_str(), res_str, a_max( EXE_STRING_LEN - 1024, 256 ),
                              true,
-                             WPUContext::PERSIST_ALL ) == WPUContext::PARSE_SUCCESS ) {
+                             WPUContext::PERSIST_NOTHING ) == WPUContext::PARSE_SUCCESS ) {
                 Lister *l1 = msg->getWorker()->getActiveLister();
                 if ( l1 != NULL ) {
                     ListerMode *lm1 = l1->getActiveMode();
@@ -414,7 +414,7 @@ ScriptOp::getDescription()
   
   sprintf( buf, "%d", stack_nr );
 #if 1
-  str1 = catalog.getLocaleCom( 44 );
+  str1 = catalog.getLocale( 1285 );
   str1 += ": ";
 #else
   str1 = "";
@@ -464,10 +464,25 @@ ScriptOp::getDescription()
       str1 += "goto ";
       str1 += ( label != NULL ) ? label : "";
       break;
-    case SCRIPT_EVALCOMMAND:
-      str1 += "evaluate ";
-      str1 += m_command_str;
-      break;
+    case SCRIPT_EVALCOMMAND: {
+        std::vector< std::string > v;
+        str1 += "evaluate ";
+        str1 += m_command_str;
+
+        AGUIXUtils::split_string( v, m_command_str, ' ' );
+
+        if ( ! v.empty() ) {
+            auto res = wconfig->getWorker()->getCommandInfo( v[0] );
+
+            if ( ! res.name.empty() ) {
+                str1 += " (";
+                str1 += res.description;
+                str1 += ")";
+            }
+        }
+
+        break;
+    }
     default:
       str1 += "nop";
       break;
@@ -1483,7 +1498,7 @@ char *ScriptOp::getRegisteredCommand()
   int endmode=-1;
   char *returnstr;
   
-  win = new AWindow( aguix, 10, 10, 10, 10, catalog.getLocale( 338 ), AWindow::AWINDOW_DIALOG );
+  win = new AWindow( aguix, 10, 10, 10, 10, catalog.getLocale( 1318 ), AWindow::AWINDOW_DIALOG );
   win->create();
 
   AContainer *ac1 = win->setContainer( new AContainer( win, 1, 3 ), true );
@@ -1503,9 +1518,13 @@ char *ScriptOp::getRegisteredCommand()
   lv->setHBarState(2);
   lv->setVBarState(2);
   lv->setDefaultColorMode( FieldListView::PRECOLOR_ONLYACTIVE );
-  lv->setNrOfFields( 1 );
+  lv->setNrOfFields( 2 );
+  lv->setGlobalFieldSpace( 5 );
   lv->setDisplayFocus( true );
   lv->setAcceptFocus( true );
+  lv->setShowHeader( true );
+  lv->setFieldText( 0, catalog.getLocale( 951 ) );
+  lv->setFieldText( 1, catalog.getLocale( 1319 ) );
 
   {
       Lister *l1 = wconfig->getWorker()->getLister( 0 );
@@ -1514,11 +1533,12 @@ char *ScriptOp::getRegisteredCommand()
           ListerMode *lm1 = l1->getActiveMode();
 
           if ( lm1 != NULL ) {
-              std::list< std::string > l = lm1->getListOfCommandsWithoutArgs();
+              auto l = lm1->getListOfCommandsWithoutArgs();
 
-              for ( auto &name : l ) {
+              for ( auto &e : l ) {
                   int trow = lv->addRow();
-                  lv->setText( trow, 0, name );
+                  lv->setText( trow, 0, e.name );
+                  lv->setText( trow, 1, e.description );
               }
           }
       }
