@@ -862,7 +862,7 @@ void SearchOpBG::createWindow()
     int w, h, sw, sh;
     initColorDefs();
 
-    m_win = new AWindow( aguix, 10, 10, 10, 10, catalog.getLocaleCom( 50 ) );
+    m_win = new AWindow( aguix, 10, 10, 10, 10, catalog.getLocale( 1291 ) );
     m_win->create();
 
     AContainer *ac1 = m_win->setContainer( new AContainer( m_win, 1, 5 ), true );
@@ -1425,7 +1425,7 @@ void SearchOpBG::setInitialVDir( std::unique_ptr< NWC::Dir > d )
 
 void SearchOpBG::updateWindowTitle()
 {
-    std::string new_title = catalog.getLocaleCom( 50 );
+    std::string new_title = catalog.getLocale( 1291 );
 
     if ( _rst != NULL ) {
 
