@@ -79,7 +79,7 @@ ShowDirCacheOp::run( WPUContext *wpu, ActionMessage *msg )
 const char *
 ShowDirCacheOp::getDescription()
 {
-  return catalog.getLocaleCom( 45 );
+  return catalog.getLocale( 1286);
 }
 
 void ShowDirCacheOp::showCacheList( ActionMessage *msg )
