@@ -142,7 +142,7 @@ StartProgOp::save(Datei *fh)
 const char *
 StartProgOp::getDescription()
 {
-  return catalog.getLocaleCom(32);
+  return catalog.getLocale(1273);
 }
 
 /* replace backslash with double backslash and backslash { and } */
@@ -488,8 +488,8 @@ int StartProgOp::doconfigure()
   const int cmin = AContainer::ACONT_MINH +
                    AContainer::ACONT_MINW;
   
-  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(32))+1);
-  sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(32));
+  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(getDescription())+1);
+  sprintf(tstr,catalog.getLocale(293),getDescription());
   win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
@@ -699,7 +699,7 @@ std::unique_ptr< StartProgOp::StartSettings > StartProgOp::showGUI()
   if ( gui_msg.length() < 1 )
     gui_msg = catalog.getLocale( 645 );
 
-  win = new AWindow( aguix, 10, 10, 10, 10, catalog.getLocaleCom( 32 ) );
+  win = new AWindow( aguix, 10, 10, 10, 10, getDescription() );
   win->create();
 
   AContainer *ac1 = win->setContainer( new AContainer( win, 1, 3 ), true );
