@@ -1,6 +1,6 @@
 /* stringcomparator.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2011-2015 Ralf Hoffmann.
+ * Copyright (C) 2011-2018 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -70,7 +70,11 @@ int StringComparator::compare( const char *s1,
 
 #ifdef HAVE_STRCASECMP
     if ( sm_use_mode == STRING_COMPARE_NOCASE ) {
-        return strcasecmp( s1, s2 );
+        int res = strcasecmp( s1, s2 );
+
+        if ( res != 0 ) return res;
+
+        // fall through to case sensitive comparison
     }
 #endif
 
