@@ -159,6 +159,9 @@ int Verzeichnis::sortfunction(void *p1,void *p2,int mode)
       case SORT_NAME:
           comp = StringComparator::compare( fe1->name, fe2->name );
           break;
+        case SORT_STRICT_NAME:
+            comp = strcmp( fe1->name, fe2->name );
+            break;
       case SORT_SIZE:
           s1=-1;
           s2=-1;
