@@ -1,6 +1,6 @@
 /* wcfiletype.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006-2014 Ralf Hoffmann.
+ * Copyright (C) 2006-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -26,12 +26,13 @@
 #include "functionproto.h"
 #include "simplelist.hh"
 #include "stringmatcher_fnmatch.hh"
+
+bool WCFiletype::s_use_extended_regex = false;
  
 WCFiletype::WCFiletype()
 {
   int i;
   name=dupstring("");
-  namelen=0;
   pattern=dupstring("");
   usepattern=false;
   usefiledesc=false;
@@ -68,6 +69,9 @@ WCFiletype::WCFiletype()
   m_magic_pattern = "";
   m_magic_compressed = false;
   m_magic_mime = false;
+  m_magic_ignore_case = false;
+
+  m_pattern_is_comma_separated = false;
 }
 
 int WCFiletype::getinternID() const
@@ -171,6 +175,9 @@ WCFiletype *WCFiletype::duplicate() const
   tft->setMagicCompressed( m_magic_compressed );
   tft->setMagicPattern( m_magic_pattern );
   tft->setMagicMime( m_magic_mime );
+  tft->setMagicIgnoreCase( m_magic_ignore_case );
+
+  tft->setPatternIsCommaSeparated( m_pattern_is_comma_separated );
 
   return tft;
 }
@@ -180,10 +187,8 @@ void WCFiletype::setName(const char *nname)
   if(name!=NULL) _freesafe(name);
   if(nname==NULL) {
     name=dupstring("");
-    namelen=0;
   } else {
     name=dupstring(nname);
-    namelen=strlen(name);
   }
 }
 
@@ -198,11 +203,13 @@ void WCFiletype::setPattern(const char *npattern)
   } else {
     pattern=dupstring(npattern);
   }
+
+  splitPattern();
 }
 
-const char *WCFiletype::getName() const
+std::string WCFiletype::getName() const
 {
-  return name;
+    return name;
 }
 
 char *WCFiletype::getPattern()
@@ -378,6 +385,8 @@ bool WCFiletype::getPatternIgnoreCase() const
 
 void WCFiletype::setPatternUseRegExp( bool nv )
 {
+    if ( m_pattern_is_comma_separated == true ) return;
+
   patternUseRegExp = nv;
 }
 
@@ -400,7 +409,8 @@ void WCFiletype::compilePatternReg()
   int erg;
 
   if ( patternRegCompiled == false ) {
-    erg = regcomp( &patternReg, pattern, REG_NOSUB | ( ( patternIgnoreCase == true ) ? REG_ICASE : 0 ) );
+    erg = regcomp( &patternReg, pattern,
+                   ( s_use_extended_regex ? REG_EXTENDED : 0 ) | REG_NOSUB | ( ( patternIgnoreCase == true ) ? REG_ICASE : 0 ) );
     if ( erg == 0 ) {
       patternRegCompiled = true;
     } else {
@@ -416,7 +426,7 @@ bool WCFiletype::patternMatchString( const char *mstr )
 #ifdef HAVE_REGEX
   int erg;
 #endif
-  char *lstr, *pstr;
+  char *lstr;
   int i;
 
   if ( strlen( pattern ) < 1 ) return false;
@@ -433,15 +443,35 @@ bool WCFiletype::patternMatchString( const char *mstr )
       for ( i = 0; lstr[i] != '\0'; i++ )
         lstr[i] = tolower( lstr[i] );
     }
-    pstr = dupstring( pattern );
-    if ( patternIgnoreCase == true ) {
-      for ( i = 0; pstr[i] != '\0'; i++ )
-        pstr[i] = tolower( pstr[i] );
-    }
+
+    if ( m_pattern_is_comma_separated ) {
+        for ( auto &s : m_pattern_split ) {
+            if ( patternIgnoreCase == true ) {
+                char *pstr = dupstring( s.c_str() );
+                for ( i = 0; pstr[i] != '\0'; i++ )
+                    pstr[i] = tolower( pstr[i] );
     
-    if ( fnmatch( pstr, lstr, 0 ) == 0 ) matched = true;
+                if ( fnmatch( pstr, lstr, 0 ) == 0 ) matched = true;
+                
+                _freesafe( pstr );
+            } else {
+                if ( fnmatch( s.c_str(), lstr, 0 ) == 0 ) matched = true;
+            }
+
+            if ( matched ) break;
+        }
+    } else {
+        char *pstr = dupstring( pattern );
+        if ( patternIgnoreCase == true ) {
+            for ( i = 0; pstr[i] != '\0'; i++ )
+                pstr[i] = tolower( pstr[i] );
+        }
+    
+        if ( fnmatch( pstr, lstr, 0 ) == 0 ) matched = true;
+        _freesafe( pstr );
+    }
+
     _freesafe( lstr );
-    _freesafe( pstr );
   } else {
 #ifdef HAVE_REGEX
     compilePatternReg();
@@ -466,7 +496,8 @@ int WCFiletype::sortfunction( void *p1, void *p2, int mode )
 
   switch ( mode ) {
     default:
-      erg = strcasecmp( ft1->getName(), ft2->getName() );
+        erg = strcasecmp( ft1->getName().c_str(),
+                          ft2->getName().c_str() );
       break;
   }
 
@@ -854,12 +885,15 @@ bool WCFiletype::save(Datei *fh) const
       fh->configPutPairBool( "magicmime", m_magic_mime );
   }
 
-  return true;
-}
+  if ( m_magic_ignore_case == true ) {
+      fh->configPutPairBool( "magicignorecase", true );
+  }
 
-int WCFiletype::getNameLen() const
-{
-  return namelen;
+  if ( m_pattern_is_comma_separated == true ) {
+      fh->configPutPairBool( "pattern_is_comma_separated", true );
+  }
+
+  return true;
 }
 
 void WCFiletype::fillNamesOfCustomActions( bool recursive, std::list<std::string> &names )
@@ -951,11 +985,6 @@ void WCFiletype::clearCustomActions()
     customaction.clear();
 }
 
-std::string WCFiletype::getNameString() const
-{
-    return name;
-}
-
 bool WCFiletype::getUseMagic() const
 {
     return m_use_magic;
@@ -990,10 +1019,10 @@ void WCFiletype::setMagicPattern( const std::string &pat )
 bool WCFiletype::magicMatch( const std::string &match_string )
 {
     if ( m_magic_matcher.getVal() == NULL ) {
-        //TODO also support regexs and case insensitive matches
+        //TODO also support regexs matches
         m_magic_matcher = new StringMatcherFNMatch();
         m_magic_matcher->setMatchString( m_magic_pattern );
-        m_magic_matcher->setMatchCaseSensitive( true );
+        m_magic_matcher->setMatchCaseSensitive( m_magic_ignore_case ? false : true );
     }
     return m_magic_matcher->match( match_string );
 }
@@ -1007,3 +1036,44 @@ void WCFiletype::setMagicMime( bool nv )
 {
     m_magic_mime = nv;
 }
+
+void WCFiletype::setUseExtendedRegEx( bool nv )
+{
+    s_use_extended_regex = nv;
+}
+ 
+bool WCFiletype::getMagicIgnoreCase() const
+{
+    return m_magic_ignore_case;
+}
+
+void WCFiletype::setMagicIgnoreCase( bool nv )
+{
+    m_magic_ignore_case = nv;
+    m_magic_matcher = NULL;
+}
+
+void WCFiletype::setPatternIsCommaSeparated( bool nv )
+{
+    if ( patternUseRegExp ) return;
+
+    m_pattern_is_comma_separated = nv;
+
+    splitPattern();
+}
+
+bool WCFiletype::getPatternIsCommaSeparated() const
+{
+    return m_pattern_is_comma_separated;
+}
+
+void WCFiletype::splitPattern()
+{
+    m_pattern_split.clear();
+
+    if ( m_pattern_is_comma_separated ) {
+        AGUIXUtils::split_string( m_pattern_split,
+                                  pattern,
+                                  ',' );
+    }
+}
