@@ -1,6 +1,6 @@
 /* wconfig.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2017 Ralf Hoffmann.
+ * Copyright (C) 2001-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -456,7 +456,7 @@ protected:
   static bool always_keep_old_key;
 
   bool configureHotkey(WCHotkey*);
-  FunctionProto *requestCommand();
+  FunctionProto *requestCommand( bool &dontConfigure );
   static int requestCommand_sf(void*,void*);
 
   bool configureButton(WCButton*);
