@@ -1,6 +1,6 @@
 /* wconfig_bookmarkcolor.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2008,2011 Ralf Hoffmann.
+ * Copyright (C) 2008-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -63,7 +63,7 @@ int BookmarkColorPanel::create()
                       NULL, NULL );
 
     ac1->add( new BevelBox( _aguix, 0, 0, 10, 2, 0 ), 0, 1, AContainer::CO_INCW );
-    ac1->add( new Text( _aguix, 0, 0, catalog.getLocale( 826 ), 1 ), 0, 2, AContainer::CO_INCW );
+    ac1->add( new Text( _aguix, 0, 0, catalog.getLocale( 826 ) ), 0, 2, AContainer::CO_INCW );
 
     AContainer *ac1_0 = ac1->add( new AContainer( this, 2, 1 ), 0, 3 );
     ac1_0->setBorderWidth( 0 );
@@ -94,7 +94,7 @@ int BookmarkColorPanel::create()
     ac1_0_1_1->setMinSpace( 0 );
     ac1_0_1_1->setMaxSpace( 0 );
 
-    m_add_label_b = (Button*)ac1_0_1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 827 ), 1, 0, 0 ),
+    m_add_label_b = (Button*)ac1_0_1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 827 ), 0 ),
                                              0, 0, AContainer::CO_FIX );
     m_add_label_b->connect( this );
 
@@ -104,7 +104,7 @@ int BookmarkColorPanel::create()
                                                                                 "",
                                                                                 0 ), 1, 0, AContainer::CO_INCW ) );
     m_label_sg->connect( this );
-    m_del_label_b = (Button*)ac1_0_1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 828 ), 1, 0, 0 ),
+    m_del_label_b = (Button*)ac1_0_1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 828 ), 0 ),
                                              2, 0, AContainer::CO_FIX );
     m_del_label_b->connect( this );
 
@@ -142,19 +142,19 @@ int BookmarkColorPanel::create()
 
     ac1_1_1->setMinHeight( 0, 0, m_lv->getHeaderHeight() );
 
-    m_norm_b[0] = (Button*)ac1_1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 32 ), 1, 0, 0 ),
+    m_norm_b[0] = (Button*)ac1_1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 32 ), 0 ),
                                          0, 1, AContainer::CO_FIX );
     m_norm_b[0]->resize( m_norm_b[0]->getWidth(), m_lv->getRowHeight() );
         
-    m_norm_b[1] = (Button*)ac1_1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 33 ), 1, 0, 0 ),
+    m_norm_b[1] = (Button*)ac1_1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 33 ), 0 ),
                                          1, 1, AContainer::CO_FIX );
     m_norm_b[1]->resize( m_norm_b[1]->getWidth(), m_lv->getRowHeight() );
     
-    m_act_b[0] = (Button*)ac1_1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 32 ), 1, 0, 0 ),
+    m_act_b[0] = (Button*)ac1_1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 32 ), 0 ),
                                          0, 2, AContainer::CO_FIX );
     m_act_b[0]->resize( m_act_b[0]->getWidth(), m_lv->getRowHeight() );
         
-    m_act_b[1] = (Button*)ac1_1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 33 ), 1, 0, 0 ),
+    m_act_b[1] = (Button*)ac1_1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 33 ), 0 ),
                                          1, 2, AContainer::CO_FIX );
     m_act_b[1]->resize( m_act_b[1]->getWidth(), m_lv->getRowHeight() );
     
