@@ -60,7 +60,7 @@ int ColorConfPanel::create()
   ac1_1->setMinSpace( 5 );
   ac1_1->setMaxSpace( 5 );
   
-  ac1_1->add( new Text( _aguix, 0, 0, catalog.getLocale( 14 ), 1 ),
+  ac1_1->add( new Text( _aguix, 0, 0, catalog.getLocale( 14 ) ),
               0, 0, AContainer::CO_FIX );
   
   sg = (StringGadget*)ac1_1->add( new StringGadget( _aguix, 0, 0, 30, buf, 0 ),
