@@ -1,6 +1,6 @@
 /* wconfig_imexport.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006,2011,2013 Ralf Hoffmann.
+ * Copyright (C) 2006-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -56,12 +56,12 @@ int ImExportPanel::create()
   ac1_1->setMinSpace( 0 );
   ac1_1->setMaxSpace( 0 );
   
-  ac1_1->add( new Text( _aguix, 0, 0, catalog.getLocale( 692 ), 1 ),
+  ac1_1->add( new Text( _aguix, 0, 0, catalog.getLocale( 692 ) ),
               0, 0, AContainer::CO_FIX );
   
   sg = (StringGadget*)ac1_1->add( new StringGadget( _aguix, 0, 0, 30, "", 0 ),
                                   1, 0, AContainer::CO_INCW );
-  fb = (Button*)ac1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 693 ), 1, 0, 0 ),
+  fb = (Button*)ac1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 693 ), 0 ),
                             2, 0, AContainer::CO_FIX );
   fb->connect( this );
   
@@ -70,11 +70,11 @@ int ImExportPanel::create()
   ac1_2->setMinSpace( 0 );
   ac1_2->setMaxSpace( 0 );
   
-  imb = (Button*)ac1_2->add( new Button( _aguix, 0, 0, catalog.getLocale( 397 ), 1, 0, 0 ),
+  imb = (Button*)ac1_2->add( new Button( _aguix, 0, 0, catalog.getLocale( 397 ), 0 ),
                              0, 0, AContainer::CO_INCW );
   imb->connect( this );
   
-  exb = (Button*)ac1_2->add( new Button( _aguix, 0, 0, catalog.getLocale( 398 ), 1, 0, 0 ),
+  exb = (Button*)ac1_2->add( new Button( _aguix, 0, 0, catalog.getLocale( 398 ), 0 ),
                              1, 0, AContainer::CO_INCW );
   exb->connect( this );
   
