@@ -1,6 +1,6 @@
 /* worker.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2017 Ralf Hoffmann.
+ * Copyright (C) 2001-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -38,6 +38,8 @@
 #include "deeppathstore.hh"
 #include <set>
 #include "kvpstore.hh"
+#include <future>
+#include "worker_types.h"
 
 class ListerMode;
 class Lister;
@@ -207,9 +209,9 @@ public:
 
     DeepPathStore &getPathStore();
 
-    void storePathPers( const std::string &path, time_t ts );
+    bool storePathPers( const std::string &path, time_t ts );
     void removePathPers( const std::string &path );
-    std::list< std::pair< std::string, time_t > > getPathsPers();
+    DeepPathStore getPathsPers();
     void relocateEntriesPers( const std::string &dest,
                               const std::string &source,
                               time_t ts,
@@ -244,6 +246,11 @@ public:
     bool getKeyChainCandidateActive() const;
 
     static KVPStore &getKVPStore();
+
+    void enqueueFuture( std::future< bool > f );
+
+    std::list< WorkerTypes::reg_command_info_t > getListOfCommandsWithoutArgs() const;
+    WorkerTypes::reg_command_info_t getCommandInfo( const std::string &command ) const;
 protected:
   void createMainWin();
   void setupMainWin();
@@ -432,6 +439,9 @@ protected:
 
     void loadWindowGeometry();
 
+    void cleanFutures();
+    void checkFutures();
+
     DeepPathStore m_path_store;
     std::unique_ptr< PersDeepPathStore > m_pers_path_store;
 
@@ -462,6 +472,8 @@ protected:
     bool m_key_chain_cand_active;
 
     TimedText m_button_help_text;
+
+    std::list< std::future< bool > > m_bool_futures;
 };
 
 #endif
