@@ -1,6 +1,6 @@
 /* worker_commands.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2018 Ralf Hoffmann.
+ * Copyright (C) 2001-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -25,7 +25,7 @@
 
 int Worker::getNrOfCommands()
 {
-  return WorkerLocale::getCatComEntry();
+  return 57;
 }
 
 FunctionProto *Worker::getCommand4ID(int id)
@@ -41,10 +41,10 @@ FunctionProto *Worker::getCommand4ID(int id)
     case 4:fpr=new UserAction();
       break;
     case 5:
-      fpr=new RowUp();
+      fpr = new ChangeColumnsOp();
       break;
     case 6:
-      fpr=new RowDown();
+      fpr = new ViewNewestFilesOp();
       break;
     case 7:
       fpr=new ChangeHiddenFlag();
@@ -53,31 +53,31 @@ FunctionProto *Worker::getCommand4ID(int id)
       fpr=new CopyOp();
       break;
     case 9:
-      fpr=new FirstRow();
+      fpr = new DirCompareOp();
       break;
     case 10:
-      fpr=new LastRow();
+      fpr = new TabProfilesOp();
       break;
     case 11:
-      fpr=new PageUp();
+      fpr = new ExternalVDirOp();
       break;
     case 12:
-      fpr=new PageDown();
+      fpr = new ChangeLayoutOp();
       break;
     case 13:
-      fpr=new SelectOp();
+      fpr = new ChTimeOp();
       break;
     case 14:
-      fpr=new SelectAllOp();
+      fpr = new PathJumpOp();
       break;
     case 15:
-      fpr=new SelectNoneOp();
+      fpr = new ClipboardOp();
       break;
     case 16:
-      fpr=new InvertAllOp();
+      fpr = new CommandMenuOp();
       break;
     case 17:
-      fpr=new ParentDirOp();
+      fpr = new VolumeManagerOp();
       break;
     case 18:
       fpr=new EnterDirOp();
@@ -119,7 +119,7 @@ FunctionProto *Worker::getCommand4ID(int id)
       fpr=new DirSizeOp();
       break;
     case 31:
-      fpr=new SimDDOp();
+      fpr = new SwitchButtonBankOp();
       break;
     case 32:
       fpr=new StartProgOp();
@@ -196,45 +196,6 @@ FunctionProto *Worker::getCommand4ID(int id)
     case 56:
       fpr = new ModifyTabsOp();
       break;
-    case 57:
-      fpr = new ChangeLayoutOp();
-      break;
-    case 58:
-      fpr = new VolumeManagerOp();
-      break;
-    case 59:
-      fpr = new SwitchButtonBankOp();
-      break;
-    case 60:
-      fpr = new PathJumpOp();
-      break;
-    case 61:
-      fpr = new ClipboardOp();
-      break;
-    case 62:
-      fpr = new CommandMenuOp();
-      break;
-    case 63:
-      fpr = new ChTimeOp();
-      break;
-    case 64:
-      fpr = new ChangeColumnsOp();
-      break;
-    case 65:
-      fpr = new ViewNewestFilesOp();
-      break;
-    case 66:
-      fpr = new DirCompareOp();
-      break;
-    case 67:
-      fpr = new TabProfilesOp();
-      break;
-    case 68:
-      fpr = new ExternalVDirOp();
-      break;
-    case 69:
-      fpr = new OpenTabMenuOp();
-      break;
     default:
       fpr=new DNDAction();
   }
@@ -249,19 +210,19 @@ int Worker::getID4Command(FunctionProto *fpr)
   else if(fpr->isName("ShowAction")==true) type=2;
   else if(fpr->isName("RawShowAction")==true) type=3;
   else if(fpr->isName("UserAction")==true) type=4;
-  else if(fpr->isName("RowUp")==true) type=5;
-  else if(fpr->isName("RowDown")==true) type=6;
+  else if ( fpr->isName( ChangeColumnsOp::name ) == true ) type = 5;
+  else if ( fpr->isName( ViewNewestFilesOp::name ) == true ) type = 6;
   else if(fpr->isName("ChangeHiddenFlag")==true) type=7;
   else if(fpr->isName("CopyOp")==true) type=8;
-  else if(fpr->isName("FirstRow")==true) type=9;
-  else if(fpr->isName("LastRow")==true) type=10;
-  else if(fpr->isName("PageUp")==true) type=11;
-  else if(fpr->isName("PageDown")==true) type=12;
-  else if(fpr->isName("SelectOp")==true) type=13;
-  else if(fpr->isName("SelectAllOp")==true) type=14;
-  else if(fpr->isName("SelectNoneOp")==true) type=15;
-  else if(fpr->isName("InvertAllOp")==true) type=16;
-  else if(fpr->isName("ParentDirOp")==true) type=17;
+  else if ( fpr->isName( DirCompareOp::name ) == true ) type = 9;
+  else if ( fpr->isName( TabProfilesOp::name ) == true ) type = 10;
+  else if ( fpr->isName( ExternalVDirOp::name ) == true ) type = 11;
+  else if ( fpr->isName( ChangeLayoutOp::name ) == true ) type = 12;
+  else if ( fpr->isName( ChTimeOp::name ) == true ) type = 13;
+  else if ( fpr->isName( PathJumpOp::name ) == true ) type = 14;
+  else if ( fpr->isName( ClipboardOp::name ) == true ) type = 15;
+  else if ( fpr->isName( CommandMenuOp::name ) == true ) type = 16;
+  else if ( fpr->isName( VolumeManagerOp::name ) == true ) type = 17;
   else if(fpr->isName("EnterDirOp")==true) type=18;
   else if(fpr->isName("ChangeListerSetOp")==true) type=19;
   else if(fpr->isName("SwitchListerOp")==true) type=20;
@@ -275,7 +236,7 @@ int Worker::getID4Command(FunctionProto *fpr)
   else if(fpr->isName("OwnOp")==true) type=28;
   else if(fpr->isName("RenameOp")==true) type=29;
   else if(fpr->isName("DirSizeOp")==true) type=30;
-  else if(fpr->isName("SimDDOp")==true) type=31;
+  else if ( fpr->isName( SwitchButtonBankOp::name ) == true ) type = 31;
   else if(fpr->isName("StartProgOp")==true) type=32;
   else if(fpr->isName("SearchEntryOp")==true) type=33;
   else if(fpr->isName("EnterPathOp")==true) type=34;
@@ -301,19 +262,6 @@ int Worker::getID4Command(FunctionProto *fpr)
   else if ( fpr->isName( OpenWorkerMenuOp::name ) == true ) type = 54;
   else if ( fpr->isName( ChangeLabelOp::name ) == true ) type = 55;
   else if ( fpr->isName( ModifyTabsOp::name ) == true ) type = 56;
-  else if ( fpr->isName( ChangeLayoutOp::name ) == true ) type = 57;
-  else if ( fpr->isName( VolumeManagerOp::name ) == true ) type = 58;
-  else if ( fpr->isName( SwitchButtonBankOp::name ) == true ) type = 59;
-  else if ( fpr->isName( PathJumpOp::name ) == true ) type = 60;
-  else if ( fpr->isName( ClipboardOp::name ) == true ) type = 61;
-  else if ( fpr->isName( CommandMenuOp::name ) == true ) type = 62;
-  else if ( fpr->isName( ChTimeOp::name ) == true ) type = 63;
-  else if ( fpr->isName( ChangeColumnsOp::name ) == true ) type = 64;
-  else if ( fpr->isName( ViewNewestFilesOp::name ) == true ) type = 65;
-  else if ( fpr->isName( DirCompareOp::name ) == true ) type = 66;
-  else if ( fpr->isName( TabProfilesOp::name ) == true ) type = 67;
-  else if ( fpr->isName( ExternalVDirOp::name ) == true ) type = 68;
-  else if ( fpr->isName( OpenTabMenuOp::name ) == true ) type = 69;
   return type;
 }
 
