@@ -1,6 +1,6 @@
 /* worker_commands.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2018 Ralf Hoffmann.
+ * Copyright (C) 2001-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -24,7 +24,6 @@
 
 #include "worker.h"
 #include "basic_actions.h"
-#include "cursorops.h"
 #include "copyop.h"
 #include "deleteop.h"
 #include "normalops.h"
@@ -33,7 +32,6 @@
 #include "ownop.h"
 #include "renameop.h"
 #include "dirsizeop.h"
-#include "simddop.h"
 #include "startprogop.h"
 #include "searchentryop.h"
 #include "enterpathop.h"
@@ -84,8 +82,6 @@
 
 #include "externalvdirop.hh"
 
-#include "opentabmenuop.hh"
-
 #endif
 
 /* Local Variables: */
