@@ -1,6 +1,6 @@
 /* worker_locale.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2018 Ralf Hoffmann.
+ * Copyright (C) 2001-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -27,8 +27,7 @@
 #include "nwc_path.hh"
 #include "datei.h"
 
-#define CATENTRY 1217
-#define CATCOMENTRY 70
+#define CATENTRY 1321
 #define CATFLAGENTRY 59
 
 WorkerLocale catalog;
@@ -38,14 +37,10 @@ WorkerLocale::WorkerLocale()
   int i;
 
   catalog=new char*[CATENTRY];
-  catalogcom=new char*[CATCOMENTRY];
   catalogflag=new char*[CATFLAGENTRY];
   for(i=0;i<CATENTRY;i++) {
     catalog[i] = NULL;
   }
-  for(i=0;i<CATCOMENTRY;i++) {
-    catalogcom[i] = NULL;
-  }
   for(i=0;i<CATFLAGENTRY;i++) {
     catalogflag[i] = NULL;
   }
@@ -1081,7 +1076,7 @@ match any font." );
   catalog[981]=dupstring( "All entries" );
   catalog[982]=dupstring( "Only subdirectories" );
   catalog[983]=dupstring( "Only direct subdirectories" );
-  catalog[984]=dupstring( "Cleanup persistent list" );
+  catalog[984]=dupstring( "Cleanup persistent list..." );
   catalog[985]=dupstring( "%d of %d entries in the persistent list of visited paths|do no longer exists, remove them from the list?" );
   catalog[986]=dupstring( "All entries still exist, nothing to remove." );
   catalog[987]=dupstring( "Show hints" );
@@ -1323,80 +1318,113 @@ The default value here is the active entry and it's already correctly protected!
   catalog[1214]=dupstring( "Unlock tab" );
   catalog[1215]=dupstring( "Move to the left" );
   catalog[1216]=dupstring( "Move to the right" );
+  catalog[1217]=dupstring( "Sort settings" );
+  catalog[1218]=dupstring( "Filter settings" );
+  catalog[1219]=dupstring( "Other settings" );
+  catalog[1220]=dupstring( "Entry filter settings" );
+  catalog[1221]=dupstring( "Configure allowed paths in Path Jump configuration to see data!" );
+  catalog[1222]=dupstring( "Last accesses by time - F1" );
+  catalog[1223]=dupstring( "Last accesses by filter - F2" );
+  catalog[1224]=dupstring( "Initial tab:" );
+  catalog[1225]=dupstring( "Show accesses by time" );
+  catalog[1226]=dupstring( "Show accesses by filter" );
+  catalog[1227]=dupstring( "Clean unused paths from database" );
+  catalog[1228]=dupstring( "Base path to use: %s" );
+  catalog[1229]=dupstring( "Unused since" );
+  catalog[1230]=dupstring( "days" );
+  catalog[1231]=dupstring( "1 week" );
+  catalog[1232]=dupstring( "1 month" );
+  catalog[1233]=dupstring( "1 year" );
+  catalog[1234]=dupstring( "Check matching entries" );
+  catalog[1235]=dupstring( "Clean unused filters" );
+  catalog[1236]=dupstring( "never used" );
+  catalog[1237]=dupstring( "No entries match the selected time period" );
+  catalog[1238]=dupstring( "%d of %d entries are older than the selected time period|Remove them from the list?" );
+  catalog[1239]=dupstring( "File extension" );
+  catalog[1240]=dupstring( "File extension sort" );
+  catalog[1241]=dupstring( "Drag'N'Drop-Action" );
+  catalog[1242]=dupstring( "DoubleClick-Action" );
+  catalog[1243]=dupstring( "Show-Action" );
+  catalog[1244]=dupstring( "RawShow-Action" );
+  catalog[1245]=dupstring( "User-Action" );
+  catalog[1246]=dupstring( "One row up" );
+  catalog[1247]=dupstring( "One row down" );
+  catalog[1248]=dupstring( "Change hidden flag" );
+  catalog[1249]=dupstring( "Copy" );
+  catalog[1250]=dupstring( "First Entry" );
+  catalog[1251]=dupstring( "Last Entry" );
+  catalog[1252]=dupstring( "Page Up" );
+  catalog[1253]=dupstring( "Page Down" );
+  catalog[1254]=dupstring( "(De)Select active entry" );
+  catalog[1255]=dupstring( "Select all entries" );
+  catalog[1256]=dupstring( "Deselect all entries" );
+  catalog[1257]=dupstring( "invert selection" );
+  catalog[1258]=dupstring( "go to parent dir" );
+  catalog[1259]=dupstring( "go to dir" );
+  catalog[1260]=dupstring( "Change list view settings" );
+  catalog[1261]=dupstring( "switch to other list view" );
+  catalog[1262]=dupstring( "pattern select" );
+  catalog[1263]=dupstring( "pattern unselect" );
+  catalog[1264]=dupstring( "path to other side" );
+  catalog[1265]=dupstring( "Quit worker" );
+  catalog[1266]=dupstring( "Delete" );
+  catalog[1267]=dupstring( "Reload" );
+  catalog[1268]=dupstring( "Make dir" );
+  catalog[1269]=dupstring( "own command" );
+  catalog[1270]=dupstring( "rename" );
+  catalog[1271]=dupstring( "directory size" );
+  catalog[1272]=dupstring( "simulate doubleclick" );
+  catalog[1273]=dupstring( "start prog" );
+  catalog[1274]=dupstring( "search entry" );
+  catalog[1275]=dupstring( "edit path (in the text field)" );
+  catalog[1276]=dupstring( "scroll listview" );
+  catalog[1277]=dupstring( "create symlink" );
+  catalog[1278]=dupstring( "change symlink" );
+  catalog[1279]=dupstring( "change permissions" );
+  catalog[1280]=dupstring( "toggle list view mode" );
+  catalog[1281]=dupstring( "set sort mode" );
+  catalog[1282]=dupstring( "set filter" );
+  catalog[1283]=dupstring( "activate shortkey from list" );
+  catalog[1284]=dupstring( "change owner" );
+  catalog[1285]=dupstring( "script" );
+  catalog[1286]=dupstring( "show directory cache" );
+  catalog[1287]=dupstring( "start action of parent type" );
+  catalog[1288]=dupstring( "do nothing" );
+  catalog[1289]=dupstring( "FTP connection" );
+  catalog[1290]=dupstring( "Internal text viewer" );
+  catalog[1291]=dupstring( "Search" );
+  catalog[1292]=dupstring( "Directory bookmarks" );
+  catalog[1293]=dupstring( "Open context menu" );
+  catalog[1294]=dupstring( "Run custom action" );
+  catalog[1295]=dupstring( "Open Worker menu" );
+  catalog[1296]=dupstring( "Change file label" );
+  catalog[1297]=dupstring( "Modify tabs" );
+  catalog[1298]=dupstring( "Change layout" );
+  catalog[1299]=dupstring( "Volume manager" );
+  catalog[1300]=dupstring( "Switch button bank" );
+  catalog[1301]=dupstring( "Path Jump" );
+  catalog[1302]=dupstring( "Copy string to clipboard" );
+  catalog[1303]=dupstring( "Command menu" );
+  catalog[1304]=dupstring( "Change file time" );
+  catalog[1305]=dupstring( "Change columns" );
+  catalog[1306]=dupstring( "View newest files" );
+  catalog[1307]=dupstring( "Compare directories" );
+  catalog[1308]=dupstring( "Tab profiles" );
+  catalog[1309]=dupstring( "External virtual dir" );
+  catalog[1310]=dupstring( "Open tab menu" );
+  catalog[1311]=dupstring( "Lock/unlock current tab" );
+  catalog[1312]=dupstring( "Open popup menu for labels" );
+  catalog[1313]=dupstring( "Recenter list view" );
+  catalog[1314]=dupstring( "Create flat view of directory" );
+  catalog[1315]=dupstring( "Create flat view of directory following symlinks" );
+  catalog[1316]=dupstring( "Virtual dir from selected entries" );
+  catalog[1317]=dupstring( "Add selected entries from other side to virtual dir" );
+  catalog[1318]=dupstring( "Select command" );
+  catalog[1319]=dupstring( "Description" );
+  catalog[1320]=dupstring( "Remove non-existing entries from the database. A non-zero 'unused days' value will only remove non-existing entries not used for longer than the given number of days." );
 
 //  catalog[]=dupstring( "" );
   
-  catalogcom[0]=dupstring( "Drag'N'Drop-Action" );
-  catalogcom[1]=dupstring( "DoubleClick-Action" );
-  catalogcom[2]=dupstring( "Show-Action" );
-  catalogcom[3]=dupstring( "RawShow-Action" );
-  catalogcom[4]=dupstring( "User-Action" );
-  catalogcom[5]=dupstring( "One row up" );
-  catalogcom[6]=dupstring( "One row down" );
-  catalogcom[7]=dupstring( "Change hidden flag" );
-  catalogcom[8]=dupstring( "Copy" );
-  catalogcom[9]=dupstring( "First Entry" );
-  catalogcom[10]=dupstring( "Last Entry" );
-  catalogcom[11]=dupstring( "Page Up" );
-  catalogcom[12]=dupstring( "Page Down" );
-  catalogcom[13]=dupstring( "(De)Select active entry" );
-  catalogcom[14]=dupstring( "Select all entries" );
-  catalogcom[15]=dupstring( "Deselect all entries" );
-  catalogcom[16]=dupstring( "invert selection" );
-  catalogcom[17]=dupstring( "go to parent dir" );
-  catalogcom[18]=dupstring( "go to dir" );
-  catalogcom[19]=dupstring( "Change list view settings" );
-  catalogcom[20]=dupstring( "switch to other list view" );
-  catalogcom[21]=dupstring( "pattern select" );
-  catalogcom[22]=dupstring( "pattern unselect" );
-  catalogcom[23]=dupstring( "path to other side" );
-  catalogcom[24]=dupstring( "Quit worker" );
-  catalogcom[25]=dupstring( "Delete" );
-  catalogcom[26]=dupstring( "Reload" );
-  catalogcom[27]=dupstring( "Make dir" );
-  catalogcom[28]=dupstring( "own command" );
-  catalogcom[29]=dupstring( "rename" );
-  catalogcom[30]=dupstring( "directory size" );
-  catalogcom[31]=dupstring( "simulate doubleclick" );
-  catalogcom[32]=dupstring( "start prog" );
-  catalogcom[33]=dupstring( "search entry" );
-  catalogcom[34]=dupstring( "edit path (in the text field)" );
-  catalogcom[35]=dupstring( "scroll listview" );
-  catalogcom[36]=dupstring( "create symlink" );
-  catalogcom[37]=dupstring( "change symlink" );
-  catalogcom[38]=dupstring( "change permissions" );
-  catalogcom[39]=dupstring( "toggle list view mode" );
-  catalogcom[40]=dupstring( "set sort mode" );
-  catalogcom[41]=dupstring( "set filter" );
-  catalogcom[42]=dupstring( "activate shortkey from list" );
-  catalogcom[43]=dupstring( "change owner" );
-  catalogcom[44]=dupstring( "script" );
-  catalogcom[45]=dupstring( "show directory cache" );
-  catalogcom[46]=dupstring( "start action of parent type" );
-  catalogcom[47]=dupstring( "do nothing" );
-  catalogcom[48]=dupstring( "FTP connection" );
-  catalogcom[49]=dupstring( "Internal text viewer" );
-  catalogcom[50]=dupstring( "Search" );
-  catalogcom[51]=dupstring( "Directory bookmarks" );
-  catalogcom[52]=dupstring( "Open context menu" );
-  catalogcom[53]=dupstring( "Run custom action" );
-  catalogcom[54]=dupstring( "Open Worker menu" );
-  catalogcom[55]=dupstring( "Change file label" );
-  catalogcom[56]=dupstring( "Modify tabs" );
-  catalogcom[57]=dupstring( "Change layout" );
-  catalogcom[58]=dupstring( "Volume manager" );
-  catalogcom[59]=dupstring( "Switch button bank" );
-  catalogcom[60]=dupstring( "Path Jump" );
-  catalogcom[61]=dupstring( "Copy string to clipboard" );
-  catalogcom[62]=dupstring( "Command menu" );
-  catalogcom[63]=dupstring( "Change file time" );
-  catalogcom[64]=dupstring( "Change columns" );
-  catalogcom[65]=dupstring( "View newest files" );
-  catalogcom[66]=dupstring( "Compare directories" );
-  catalogcom[67]=dupstring( "Tab profiles" );
-  catalogcom[68]=dupstring( "External virtual dir" );
-  catalogcom[69]=dupstring( "Open tab menu" );
-  
   catalogflag[0]=dupstring( "String requester" );
   catalogflag[1]=dupstring( "path" );
   catalogflag[2]=dupstring( "other path" );
@@ -1462,7 +1490,6 @@ WorkerLocale::~WorkerLocale()
 {
   freeLanguage();
   delete [] catalog;
-  delete [] catalogcom;
   delete [] catalogflag;
 }
 
@@ -1520,11 +1547,6 @@ int WorkerLocale::loadLanguage(const char *name)
     parse(file,0);
     file->close();
 
-    if(openCatFile(file,name,".coms")==0) {
-      parse(file,1);
-      file->close();
-    }
-
     if(openCatFile(file,name,".flags")==0) {
       parse(file,2);
       file->close();
@@ -1617,13 +1639,6 @@ void WorkerLocale::parse(Datei *file,int cat)
                   catalog[entrynr]=tstr;
                 } else _freesafe(tstr);
                 break;
-              case 1:
-                // com
-                if(entrynr<CATCOMENTRY) {
-                  if ( catalogcom[entrynr] != NULL ) _freesafe( catalogcom[entrynr] );
-                  catalogcom[entrynr]=tstr;
-                } else _freesafe(tstr);
-                break;
               case 2:
                 // flag
                 if(entrynr<CATFLAGENTRY) {
@@ -1695,10 +1710,6 @@ void WorkerLocale::freeLanguage()
     if ( catalog[i] != NULL ) _freesafe(catalog[i]);
     catalog[i] = NULL;
   }
-  for(i=0;i<CATCOMENTRY;i++) {
-    if ( catalogcom[i] != NULL ) _freesafe(catalogcom[i]);
-    catalogcom[i] = NULL;
-  }
   for(i=0;i<CATFLAGENTRY;i++) {
     if ( catalogflag[i] != NULL ) _freesafe(catalogflag[i]);
     catalogflag[i] = NULL;
@@ -1712,22 +1723,9 @@ const char *WorkerLocale::getLocale(int index2)
   return catalog[index2];
 }
 
-const char *WorkerLocale::getLocaleCom(int index2)
-{
-  if((index2<0)||(index2>=CATCOMENTRY)) return "?";
-  if ( catalogcom[index2] == NULL ) return "?";
-  return catalogcom[index2];
-}
-
 const char *WorkerLocale::getLocaleFlag(int index2)
 {
   if((index2<0)||(index2>=CATFLAGENTRY)) return "?";
   if ( catalogflag[index2] == NULL ) return "?";
   return catalogflag[index2];
 }
-
-int WorkerLocale::getCatComEntry()
-{
-  return CATCOMENTRY;
-}
-
