@@ -101,7 +101,13 @@ public:
       PARSE_ERROR
   } parse_com_str_t;
 
-  parse_com_str_t parse( const char *str1, std::string &return_str, int maxlen, bool quote = true );
+  typedef enum {
+      PERSIST_ALL,
+      PERSIST_FLAGS,
+      PERSIST_NOTHING
+  } parse_persist_t;
+
+  parse_com_str_t parse( const char *str1, std::string &return_str, int maxlen, bool quote, parse_persist_t persist );
 
   #define IFP_BUFSIZE 1024
   #define IFP_SYMTABLE_MAX 128
